# Generated by Django 3.0.2 on 2020-01-27 07:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0124_auto_20200123_0314'),
    ]

    operations = [
        migrations.AddField(
            model_name='lotsman_documents_hierarcy',
            name='path',
            field=models.TextField(blank=True, null=True),
        ),
    ]
