# Generated by Django 2.2.8 on 2019-12-06 21:52

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0154_auto_20191206_1937'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launch_operations_item',
            name='disabled_launch',
        ),
        migrations.AlterField(
            model_name='launch_operations_item',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=1),
        ),
    ]
