# Generated by Django 2.2.6 on 2019-10-13 11:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0013_auto_20191013_1141'),
    ]

    operations = [
        migrations.RenameField(
            model_name='user_add_info',
            old_name='ip',
            new_name='description',
        ),
    ]
