# Generated by Django 2.2.5 on 2019-09-18 14:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0054_delete_demand'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='precent',
            unique_together=set(),
        ),
    ]
