# Generated by Django 3.0.3 on 2020-02-27 16:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0217_operations_template_detail_description'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operations_template_detail',
            unique_together={('operation', 'template')},
        ),
    ]
