# Generated by Django 3.0.4 on 2020-03-05 17:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0228_remove_launch_item_line_spc_clm_count_per_one'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='resource',
            name='Resource_unique_constraint_1',
        ),
    ]
