# Generated by Django 3.0.3 on 2020-02-13 12:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0178_auto_20200210_0856'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launches',
            name='props',
        ),
    ]
