# Generated by Django 3.0.3 on 2020-02-17 09:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0092_auto_20200217_0914'),
    ]

    operations = [
        migrations.AlterField(
            model_name='levels',
            name='code',
            field=models.PositiveIntegerField(),
        ),
    ]
