# Generated by Django 2.2 on 2019-04-25 19:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0008_auto_20190425_1925'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_plan_template_locations',
            name='item_line',
        ),
    ]
