# Generated by Django 2.2.6 on 2019-10-22 07:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0075_auto_20191022_0721'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('prod_item', 'item', 'num')},
        ),
    ]
