# Generated by Django 2.2 on 2019-04-14 17:01

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0018_auto_20190414_1616'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='item_line',
            name='item',
        ),
        migrations.AddField(
            model_name='item_line',
            name='item_child',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='item_child', to='ckk.Item', verbose_name='Товарная позиция'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='item_parent',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, related_name='item_parent', to='ckk.Item', verbose_name='Товарная позиция'),
        ),
        migrations.DeleteModel(
            name='Item_refs',
        ),
    ]
