# Generated by Django 2.2.5 on 2019-09-18 14:45

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0057_dogovors'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='dogovors',
            name='document',
        ),
        migrations.AlterField(
            model_name='precent',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='document_p', to='sales.Dogovors'),
        ),
    ]
