# Generated by Django 2.2.2 on 2019-06-07 18:52

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0034_document_attr_cross_document_attributes'),
        ('ckk', '0079_auto_20190607_1721'),
    ]

    operations = [
        migrations.AddField(
            model_name='item_line',
            name='STMP_1',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='STMP_1', to='kd.Document_attributes', verbose_name='Наименование'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='STMP_2',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='STMP_1', to='kd.Document_attributes', verbose_name='Обозначение'),
        ),
        migrations.AlterUniqueTogether(
            name='item_line',
            unique_together={('parent', 'child'), ('STMP_1', 'STMP_2')},
        ),
        migrations.RemoveField(
            model_name='item_line',
            name='SPC_CLM_MARK',
        ),
        migrations.RemoveField(
            model_name='item_line',
            name='SPC_CLM_NAME',
        ),
    ]
