# Generated by Django 2.2.1 on 2019-06-05 10:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0047_auto_20190530_1353'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='resource',
            name='category',
        ),
        migrations.DeleteModel(
            name='Resource_categories',
        ),
    ]
