# Generated by Django 2.2.1 on 2019-05-22 12:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0054_auto_20190521_2304'),
        ('production', '0021_auto_20190522_1242'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operation_plan_templates',
            unique_together={('code', 'item')},
        ),
    ]
