# Generated by Django 3.0.2 on 2020-01-21 10:16

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0073_auto_20200121_0739'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_refs',
            name='child',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='operation_child', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_refs',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='operation_parent', to='planing.Operations'),
        ),
    ]
