# Generated by Django 2.2.6 on 2019-10-28 20:25

from django.db import migrations

import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0097_auto_20191028_1750'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dogovors',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(),
        ),
    ]
