# Generated by Django 3.0.2 on 2020-01-17 16:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0057_auto_20191209_1131'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='operation_launches',
            options={'verbose_name': 'Кросс таблица'},
        ),
    ]
