# Generated by Django 2.2.6 on 2019-10-31 17:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0084_auto_20191014_1326'),
    ]

    operations = [
        migrations.RunSQL(
            sql=r'CREATE INDEX "kd_document_attributes_value_str_idx" ON "kd_document_attributes" (UPPER("value_str"));',
            reverse_sql=r'DROP INDEX "kd_document_attributes_value_str_idx";'
        )
    ]
