# Generated by Django 2.2.7 on 2019-11-17 17:58

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0095_launch_item_refs'),
    ]

    operations = [
        migrations.AddField(
            model_name='launch_item_line',
            name='launch',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='production.Launches'),
        ),
        migrations.AddField(
            model_name='launch_item_refs',
            name='launch',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='production.Launches'),
        ),
        migrations.AlterField(
            model_name='launch_item_line',
            name='child',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_child', to='ckk.Item', verbose_name='Товарная позиция'),
        ),
        migrations.AlterField(
            model_name='launch_item_line',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_parent', to='ckk.Item', verbose_name='Товарная позиция'),
        ),
        migrations.AlterField(
            model_name='launch_item_refs',
            name='child',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='launch_child', to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='launch_item_refs',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='launch_parent', to='ckk.Item'),
        ),
        migrations.DeleteModel(
            name='Launch_items',
        ),
    ]
