# Generated by Django 2.2.4 on 2019-08-20 10:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0143_files_askon'),
    ]

    operations = [
        migrations.AlterField(
            model_name='material_askon',
            name='field0',
            field=models.CharField(db_index=True, max_length=255, verbose_name='Информация в дерево материалов'),
        ),
    ]
