# Generated by Django 3.0.3 on 2020-03-01 03:54

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0119_delete_operation_attr'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations',
            name='num',
            field=isc_common.fields.code_field.CodeStrictField(blank=True, null=True),
        ),
    ]
