# Generated by Django 2.2.4 on 2019-08-22 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0009_auto_20190820_1236'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user_add_info',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='user_positions',
            name='id_old',
        ),
    ]
