# Generated by Django 2.2.8 on 2019-12-07 18:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0042_auto_20191207_1820'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations',
            name='level',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
