# Generated by Django 2.2.6 on 2019-10-28 21:05

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0099_auto_20191028_2105'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dogovors',
            name='customer',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='sales.Customer'),
        ),
        migrations.AlterField(
            model_name='dogovors',
            name='status',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='sales.StatusDogovor'),
        ),
        migrations.AlterField(
            model_name='dogovors',
            name='type',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='sales.Dogovor_types'),
        ),
    ]
