# Generated by Django 2.2.4 on 2019-08-30 17:45

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0149_remove_status_code_owner'),
    ]

    operations = [
        migrations.AddField(
            model_name='status',
            name='code_owner',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]
