# Generated by Django 2.2.3 on 2019-07-28 19:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0073_remove_document_attr_cross_props'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pathes',
            name='prefix',
        ),
        migrations.AddField(
            model_name='pathes',
            name='drive',
            field=models.CharField(blank=True, max_length=10, null=True, verbose_name='Диск'),
        ),
        migrations.AlterModelTable(
            name='documents_view',
            table='kd_documents_view',
        ),
    ]
