# Generated by Django 3.0.3 on 2020-02-16 19:08

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0183_ready_2_launch_detail_item_full_name_obj'),
    ]

    operations = [
        migrations.AddField(
            model_name='ready_2_launch_detail',
            name='mat_view_name',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]
