# Generated by Django 2.2.3 on 2019-07-20 06:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0065_documents_history'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Documents_history',
        ),
    ]
