# Generated by Django 2.2.1 on 2019-05-28 17:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0041_auto_20190528_1709'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='precent',
            unique_together={('code', 'type')},
        ),
    ]
