# Generated by Django 2.2.7 on 2019-11-22 09:20

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0160_ed_izm_props'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ed_izm',
            name='props',
            field=bitfield.models.BitField((('root_timevalue', 'Базовая временная единица'),), db_index=True, default=0),
        ),
    ]
