# Generated by Django 3.0.4 on 2020-03-26 19:22

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0143_auto_20200318_1337'),
    ]

    operations = [
        migrations.AddField(
            model_name='uploades',
            name='props',
            field=bitfield.models.BitField((('confirmed', 'Подтверждено'),), db_index=True, default=1),
        ),
    ]
