# Generated by Django 2.2.4 on 2019-08-20 10:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0144_auto_20190820_1057'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='material_askon',
            unique_together={('field0', 'field1', 'field2', 'field3', 'field4', 'field5', 'field6', 'field7')},
        ),
    ]
