# Generated by Django 2.2.7 on 2019-11-20 15:40

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0130_auto_20191120_1523'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'), ('added', 'Добавлено в данную производственную спецификацию'), ('edited', 'Добавлено в данную производственную спецификацию')), db_index=True, default=1),
        ),
    ]
