# Generated by Django 2.2.2 on 2019-06-25 12:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0049_auto_20190624_1358'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='pathes_view',
            table='kd_pathes_view',
        ),
    ]
