# Generated by Django 2.2.8 on 2019-12-07 18:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0158_auto_20191207_1031'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_operations_item',
            name='num',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='launch_operations_item',
            name='qty',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
