# Generated by Django 2.2.7 on 2019-11-19 10:32

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0115_auto_20191119_1031'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_operations_item',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'), ('added', 'Добавлено в данную производственную спецификацию'), ('edited', 'Изменено в данной производственной спецификации'), ('refreshed', 'Просмотрено при переформировании')), db_index=True, default=0),
        ),
    ]
