# Generated by Django 2.2 on 2019-04-25 18:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0003_operation_plan_template_locations_distribution_coefficient'),
    ]

    operations = [
        migrations.RenameField(
            model_name='operation_plan_template_locations',
            old_name='location',
            new_name='locations',
        ),
    ]
