# Generated by Django 2.2.1 on 2019-05-24 09:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0031_remove_demand_customer'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='demand',
            name='deliverydate',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='maxlateness',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='minshipment',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='priority',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='quantity',
        ),
    ]
