# Generated by Django 3.0.3 on 2020-02-17 15:52

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0193_auto_20200217_1355'),
    ]

    operations = [
        migrations.AddField(
            model_name='launches',
            name='facets',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
    ]
