# Generated by Django 2.2.4 on 2019-08-30 17:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0148_auto_20190826_1127'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='status',
            name='code_owner',
        ),
    ]
