# Generated by Django 2.2.8 on 2019-12-18 16:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0120_auto_20191218_1014'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='lotsman_document_attr_cross',
            unique_together=set(),
        ),
    ]
