# Generated by Django 3.0.3 on 2020-03-01 09:10

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0121_auto_20200301_0511'),
    ]

    operations = [
        migrations.AlterField(
            model_name='status_operation_types',
            name='opertype',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='planing.Operation_types'),
        ),
        migrations.AlterModelTable(
            name='production_order',
            table=None,
        ),
    ]
