# Generated by Django 3.0.3 on 2020-02-08 07:14

from django.db import migrations
import django_db_constraints.operations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0192_auto_20200206_1540'),
    ]

    operations = [
        django_db_constraints.operations.AlterConstraints(
            name='item',
            db_constraints={'Item_not_null_STMP1_STMP2': 'CHECK ("STMP_1_id" IS NOT NULL OR "STMP_2_id" IS NOT NULL)'},
        ),
    ]
