# Generated by Django 2.2.6 on 2019-10-22 07:21

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0074_item_refs'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations_item',
            name='prod_item',
            field=isc_common.fields.related.ForeignKeySetNull(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='op_prod_item', to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='operations_item',
            name='item',
            field=isc_common.fields.related.ForeignKeySetNull(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='op_item', to='ckk.Item'),
        ),
        migrations.AlterUniqueTogether(
            name='item_refs',
            unique_together={('item', 'child', 'parent')},
        ),
    ]
