# Generated by Django 3.0.3 on 2020-02-06 14:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0127_auto_20200131_1121'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='documents_thumb',
            unique_together={('document', 'lotsman_document', 'path')},
        ),
        migrations.AlterUniqueTogether(
            name='documents_thumb10',
            unique_together={('document', 'lotsman_document', 'path')},
        ),
    ]
