# Generated by Django 3.0.3 on 2020-02-09 11:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0174_auto_20200209_1126'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='launch_operation_resources',
            constraint=models.UniqueConstraint(condition=models.Q(('location', None), ('resource', None)), fields=('launch_operationitem',), name='Launch_operation_resources_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='launch_operation_resources',
            constraint=models.UniqueConstraint(condition=models.Q(location=None), fields=('launch_operationitem', 'resource'), name='Launch_operation_resources_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='launch_operation_resources',
            constraint=models.UniqueConstraint(condition=models.Q(resource=None), fields=('launch_operationitem', 'location'), name='Launch_operation_resources_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='launch_operation_resources',
            constraint=models.UniqueConstraint(fields=('launch_operationitem', 'location', 'resource'), name='Launch_operation_resources_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='launch_operations_material',
            constraint=models.UniqueConstraint(condition=models.Q(('material', None), ('material_askon', None)), fields=('launch_operationitem',), name='Launch_operations_material_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='launch_operations_material',
            constraint=models.UniqueConstraint(condition=models.Q(material_askon=None), fields=('launch_operationitem', 'material'), name='Launch_operations_material_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='launch_operations_material',
            constraint=models.UniqueConstraint(condition=models.Q(material=None), fields=('launch_operationitem', 'material_askon'), name='Launch_operations_material_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='launch_operations_material',
            constraint=models.UniqueConstraint(fields=('launch_operationitem', 'material', 'material_askon'), name='Launch_operations_material_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='operation_def_resources',
            constraint=models.UniqueConstraint(condition=models.Q(('location', None), ('resource', None)), fields=('operation',), name='Operation_def_resources_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='operation_def_resources',
            constraint=models.UniqueConstraint(condition=models.Q(location=None), fields=('operation', 'resource'), name='Operation_def_resources_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='operation_def_resources',
            constraint=models.UniqueConstraint(condition=models.Q(resource=None), fields=('location', 'operation'), name='Operation_def_resources_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='operation_def_resources',
            constraint=models.UniqueConstraint(fields=('location', 'operation', 'resource'), name='Operation_def_resources_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='operation_material',
            constraint=models.UniqueConstraint(condition=models.Q(('material', None), ('material_askon', None)), fields=('operationitem',), name='Operation_material_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='operation_material',
            constraint=models.UniqueConstraint(condition=models.Q(material_askon=None), fields=('material', 'operationitem'), name='Operation_material_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='operation_material',
            constraint=models.UniqueConstraint(condition=models.Q(material=None), fields=('material_askon', 'operationitem'), name='Operation_material_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='operation_material',
            constraint=models.UniqueConstraint(fields=('material', 'material_askon', 'operationitem'), name='Operation_material_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='operation_resources',
            constraint=models.UniqueConstraint(condition=models.Q(('location', None), ('resource', None)), fields=('operationitem',), name='Operation_resources_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='operation_resources',
            constraint=models.UniqueConstraint(condition=models.Q(location=None), fields=('operationitem', 'resource'), name='Operation_resources_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='operation_resources',
            constraint=models.UniqueConstraint(condition=models.Q(resource=None), fields=('location', 'operationitem'), name='Operation_resources_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='operation_resources',
            constraint=models.UniqueConstraint(fields=('location', 'operationitem', 'resource'), name='Operation_resources_unique_constraint_3'),
        ),
    ]
