# Generated by Django 3.0.3 on 2020-03-02 04:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0226_launch_item_refs_qty_per_one'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs',
            name='qty_per_one',
            field=models.FloatField(blank=True, null=True),
        ),
    ]
