# Generated by Django 2.2.6 on 2019-10-14 01:21

import bitfield.models
from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0154_auto_20191010_2032'),
    ]

    operations = [
        migrations.CreateModel(
            name='Item_operations_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('parent_id', models.BigIntegerField()),
                ('relevant', isc_common.fields.name_field.NameField(blank=True, null=True)),
                ('where_from', isc_common.fields.name_field.NameField(blank=True, null=True)),
                ('props', bitfield.models.BitField((('relevant', 'Актуальность'), ('from_cdw', 'Получено из чертежа'), ('from_spw', 'Получено из спецификации'), ('for_line', 'Строка спецификации'), ('from_pdf', 'Получено из бумажного архива'), ('man_input', 'Занесено вручную'), ('copied', 'Скопировано')), db_index=True, default=1)),
                ('version', models.PositiveIntegerField(blank=True, null=True)),
                ('qty_operations', models.PositiveIntegerField()),
                ('isFolder', models.BooleanField()),
            ],
            options={
                'verbose_name': 'Товарная позиция',
                'db_table': 'ckk_item_view',
                'managed': False,
            },
        ),
    ]
