# Generated by Django 2.2.8 on 2019-12-04 14:24

from django.db import migrations
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0137_auto_20191204_1424'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations',
            name='name',
            field=isc_common.fields.name_field.NameStrictField(),
        ),
    ]
