# Generated by Django 3.0.3 on 2020-02-23 05:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0200_resource_props'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='resource',
            name='Resource_unique_constraint_0',
        ),
        migrations.RemoveConstraint(
            model_name='resource',
            name='Resource_unique_constraint_1',
        ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(condition=models.Q(calendar=None), fields=('location', 'props'), name='Resource_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(fields=('calendar', 'location', 'props'), name='Resource_unique_constraint_1'),
        ),
    ]
