# Generated by Django 2.2.2 on 2019-06-28 08:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0050_auto_20190625_1220'),
    ]

    operations = [
        migrations.AddField(
            model_name='documents',
            name='load_error',
            field=models.TextField(blank=True, null=True),
        ),
    ]
