# Generated by Django 3.0.2 on 2020-01-17 08:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0182_auto_20200115_0959'),
    ]

    operations = [
        migrations.RunSQL(
            'update ckk_item_refs set props = 3'
        )
    ]
