# Generated by Django 2.2.8 on 2019-12-09 12:55

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0162_auto_20191208_0900'),
    ]

    operations = [
        migrations.AddField(
            model_name='launches',
            name='props',
            field=bitfield.models.BitField((('routing_maked', 'Маршрутизация выполнена'),), db_index=True, default=0),
        ),
    ]
