# Generated by Django 3.0.2 on 2020-01-27 16:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0125_lotsman_documents_hierarcy_path'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='lotsman_documents_hierarcy',
            name='path',
        ),
    ]
