# Generated by Django 2.2.3 on 2019-07-02 14:40

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.code_field
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0118_auto_20190701_1712'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_line',
            name='section',
            field=isc_common.fields.code_field.CodeStrictField(),
        ),
        migrations.AlterField(
            model_name='material_params',
            name='param_type',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='refs.Type_param'),
        ),
    ]
