# Generated by Django 2.2.7 on 2019-11-21 21:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0159_auto_20191119_2034'),
        ('production', '0132_auto_20191120_1547'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='launch_operations_item',
            unique_together={('item', 'num', 'launch', 'operation')},
        ),
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('item', 'num', 'operation')},
        ),
    ]
