# Generated by Django 2.2.7 on 2019-11-22 09:15

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0159_auto_20191119_2034'),
    ]

    operations = [
        migrations.AddField(
            model_name='ed_izm',
            name='props',
            field=bitfield.models.BitField((('root_timevalue', 'Базовая временная еденица'),), db_index=True, default=0),
        ),
    ]
