# Generated by Django 2.2.1 on 2019-05-20 12:58

from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0006_delete_operation_plan_types'),
    ]

    operations = [
        migrations.CreateModel(
            name='User_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('username', isc_common.fields.code_field.CodeField(verbose_name='логин')),
                ('first_name', isc_common.fields.name_field.NameField(verbose_name='имя')),
                ('last_name', isc_common.fields.name_field.NameField(verbose_name='фамилия')),
                ('email', models.EmailField(blank=True, max_length=254, null=True, verbose_name='E-mail')),
                ('middle_name', isc_common.fields.name_field.NameField(verbose_name='отчетво')),
                ('position_name', isc_common.fields.name_field.NameField(verbose_name='должность')),
                ('location_name', isc_common.fields.name_field.NameField(verbose_name='место работы')),
            ],
            options={
                'verbose_name': 'Пользователи',
                'db_table': 'user_view',
                'managed': False,
            },
        ),
    ]
