# Generated by Django 3.0.3 on 2020-02-22 17:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0140_auto_20200212_0751'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attributes',
            name='value_int',
            field=models.FloatField(blank=True, db_index=True, null=True, verbose_name='Значение атрибута'),
        ),
    ]
