# Generated by Django 2.2.2 on 2019-06-13 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0047_auto_20190612_2301'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attributes',
            name='value_str',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Значение атрибута'),
        ),
    ]
