# Generated by Django 2.2.8 on 2019-12-09 11:31

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0056_operation_level'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_launches',
            name='launch',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='planing_resource_launch', to='production.Launches'),
        ),
    ]
