# Generated by Django 2.2.1 on 2019-05-22 12:56

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0022_auto_20190522_1243'),
        ('sales', '0022_auto_20190522_1125'),
    ]

    operations = [
        migrations.AddField(
            model_name='precent',
            name='operation_plan_templates',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Operation_plan_templates'),
        ),
    ]
