# Generated by Django 2.2.6 on 2019-10-28 21:34

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0101_auto_20191028_2108'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dogovors',
            name='date',
            field=models.DateTimeField(db_index=True, default=django.utils.timezone.now, verbose_name='Дата'),
        ),
    ]
