# Generated by Django 2.2.8 on 2019-12-08 08:12

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0159_auto_20191207_1801'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_operation_resources',
            name='location',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='ckk.Locations'),
        ),
        migrations.AlterField(
            model_name='launch_operation_resources',
            name='resource',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='production.Resource'),
        ),
    ]
