# Generated by Django 2.2.7 on 2019-11-18 21:28

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0110_auto_20191118_2127'),
    ]

    operations = [
        migrations.AddField(
            model_name='launch_item_refs',
            name='launch',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='production.Launches'),
        ),
        migrations.AlterUniqueTogether(
            name='launch_item_refs',
            unique_together={('parent', 'child', 'launch')},
        ),
    ]
