# Generated by Django 2.2.2 on 2019-06-10 01:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0044_document_attr_cross_position_in_document'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attr_cross',
            name='position_in_document',
            field=models.PositiveIntegerField(),
        ),
    ]
