# Generated by Django 2.2.1 on 2019-05-22 07:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0017_auto_20190522_0746'),
    ]

    operations = [
        migrations.AlterField(
            model_name='precent',
            name='date',
            field=models.DateTimeField(db_index=True, default=None, verbose_name='Дата'),
        ),
        migrations.AlterField(
            model_name='precent',
            name='date_sign',
            field=models.DateTimeField(db_index=True, default=None, verbose_name='Дата подписания'),
        ),
        migrations.AlterUniqueTogether(
            name='precent',
            unique_together={('code', 'type', 'date')},
        ),
    ]
