# Generated by Django 3.0.3 on 2020-02-07 08:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0192_auto_20200206_1540'),
        ('kd', '0130_auto_20200206_1526'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='document_attributes',
            unique_together={('attr_type', 'value_str')},
        ),
    ]
