# Generated by Django 3.0.3 on 2020-02-23 12:22

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0201_auto_20200223_0522'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations',
            name='props',
            field=bitfield.models.BitField((('assemly', 'Операция комплектации'), ('made_common_form', 'Формировать общий документ')), db_index=True, default=0),
        ),
    ]
