# Generated by Django 3.0.2 on 2020-01-22 16:13

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ckk', '0186_locations_users_parent'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='locations_users',
            unique_together={('location', 'user')},
        ),
    ]
