# Generated by Django 3.0.3 on 2020-02-06 12:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0127_auto_20200131_1121'),
        ('ckk', '0190_auto_20200131_1105'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='lotsman_type_id',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2', 'version', 'lotsman_type_id')},
        ),
    ]
