# Generated by Django 3.0.3 on 2020-02-26 08:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0208_auto_20200223_1613'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Resource_view',
        ),
        migrations.RemoveField(
            model_name='resource',
            name='props',
        ),
    ]
