# Generated by Django 2.2.2 on 2019-06-06 18:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0032_auto_20190530_1706'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='documents_view',
            table='kd_documents_view',
        ),
    ]
