# Generated by Django 2.2.8 on 2019-12-12 20:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0172_auto_20191212_2039'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_refs',
            name='syntetic_child',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='syntetic_child', to='ckk.Item'),
        ),
    ]
