# Generated by Django 2.2.1 on 2019-05-24 09:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0035_auto_20190524_0932'),
    ]

    operations = [
        migrations.AlterField(
            model_name='precent',
            name='date',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата'),
        ),
    ]
