# Generated by Django 2.2.7 on 2019-11-19 18:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0124_auto_20191119_1811'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='launch_item_line_view',
            table='production_launch_item_line_view',
        ),
        migrations.AlterModelTable(
            name='launch_item_view',
            table='production_launch_item_view',
        ),
    ]
