# Generated by Django 2.2.6 on 2019-10-23 22:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0090_auto_20191023_2206'),
    ]

    operations = [
        migrations.RenameField(
            model_name='precent_materials',
            old_name='precent',
            new_name='precent_item',
        ),
    ]
