# Generated by Django 2.2.1 on 2019-05-21 20:28

from django.db import migrations, models
import isc_common.fields.files
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0015_merge_20190521_1855'),
    ]

    operations = [
        migrations.AddField(
            model_name='precent',
            name='attfile',
            field=isc_common.fields.files.FileFieldEx(blank=True, default=None, max_length=255, null=True, upload_to='', verbose_name='Файл'),
        ),
        migrations.AddField(
            model_name='precent',
            name='file_store',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Каталог хранения файла'),
        ),
        migrations.AddField(
            model_name='precent',
            name='format',
            field=isc_common.fields.name_field.NameField(verbose_name='Формат файла'),
        ),
        migrations.AddField(
            model_name='precent',
            name='key',
            field=models.BinaryField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='precent',
            name='mime_type',
            field=isc_common.fields.name_field.NameField(blank=True, default=None, null=True, verbose_name='MIME тип файла файла'),
        ),
        migrations.AddField(
            model_name='precent',
            name='real_name',
            field=models.TextField(blank=True, default=None, null=True, verbose_name='Первоначальное имя файла'),
        ),
        migrations.AddField(
            model_name='precent',
            name='size',
            field=models.BigIntegerField(default=0, verbose_name='Размер фала'),
        ),
    ]
