# Generated by Django 2.2.8 on 2019-12-07 18:01

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0159_auto_20191207_1801'),
        ('ckk', '0163_locations_users'),
        ('planing', '0037_auto_20191207_1312'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_launch_operation_material',
            name='launch_operation_material',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operation_resources',
            name='launch_operation_resources',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operations_item',
            name='launch_operations_item',
        ),
        migrations.AddField(
            model_name='operation_launch_operation_material',
            name='edizm',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AddField(
            model_name='operation_launch_operation_material',
            name='material',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Materials'),
        ),
        migrations.AddField(
            model_name='operation_launch_operation_material',
            name='material_askon',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Material_askon'),
        ),
        migrations.AddField(
            model_name='operation_launch_operation_material',
            name='qty',
            field=models.DecimalField(decimal_places=4, default=0.0, max_digits=10),
        ),
        migrations.AddField(
            model_name='operation_launch_operation_resources',
            name='location',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
        migrations.AddField(
            model_name='operation_launch_operation_resources',
            name='resource',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Resource'),
        ),
        migrations.AddField(
            model_name='operation_launch_operations_item',
            name='ed_izm',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AddField(
            model_name='operation_launch_operations_item',
            name='num',
            field=models.PositiveIntegerField(default=None),
        ),
        migrations.AddField(
            model_name='operation_launch_operations_item',
            name='qty',
            field=models.PositiveIntegerField(default=None),
        ),
        migrations.AlterField(
            model_name='operation_launch_operations_item',
            name='operation',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operations',
            name='value',
            field=models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True),
        ),
    ]
