# Generated by Django 2.2 on 2019-04-14 04:29

from django.db import migrations
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0009_auto_20190413_1750'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='documents_thumb10',
            managers=[
                ('object', django.db.models.manager.Manager()),
            ],
        ),
    ]
