# Generated by Django 2.2.3 on 2019-07-31 22:27

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0052_auto_20190709_1032'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations_item',
            name='ed_izm',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, default=None, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AlterField(
            model_name='operations_item',
            name='qty',
            field=models.PositiveIntegerField(blank=True, default=None, null=True),
        ),
    ]
