# Generated by Django 2.2 on 2019-04-13 15:24

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0007_auto_20190413_1215'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documents',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('beenItemed', 'Был внесен в состав изделий')), default=1),
        ),
    ]
