# Generated by Django 3.0.3 on 2020-02-19 14:46

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0101_auto_20200219_0500'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operations_view',
            name='location',
        ),
        migrations.AddField(
            model_name='operations_view',
            name='mark',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]
