# Generated by Django 2.2.1 on 2019-05-24 09:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0028_auto_20190523_1753'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Описание'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='full_name',
            field=models.TextField(blank=True, null=True, verbose_name='Полное наименование'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='name',
            field=models.CharField(db_index=True, max_length=255, verbose_name='Наименование'),
        ),
    ]
