# Generated by Django 2.2.1 on 2019-05-28 21:55

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0062_auto_20190528_1534'),
        ('sales', '0043_auto_20190528_2049'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Precent_items_view',
        ),
        migrations.AddField(
            model_name='precent_items',
            name='location',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
    ]
