# Generated by Django 2.2.4 on 2019-08-20 12:35

from django.db import migrations, models
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0007_user_view'),
    ]

    operations = [
        migrations.AddField(
            model_name='user_add_info',
            name='comp_name',
            field=isc_common.fields.name_field.NameField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='user_add_info',
            name='ip',
            field=models.IPAddressField(blank=True, null=True),
        ),
    ]
