# Generated by Django 2.2.6 on 2019-10-18 13:16

from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field
import isc_common.fields.description_field
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0064_auto_20191018_1159'),
    ]

    operations = [
        migrations.CreateModel(
            name='Dogovors_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('code', isc_common.fields.code_field.CodeField(blank=True, null=True)),
                ('isFolder', models.BooleanField()),
                ('description', isc_common.fields.description_field.DescriptionField()),
                ('size', models.BigIntegerField(default=0, verbose_name='Размер фала')),
                ('real_name', models.TextField(blank=True, default=None, null=True, verbose_name='Первоначальное имя файла')),
                ('mime_type', isc_common.fields.name_field.NameField(blank=True, default=None, null=True, verbose_name='MIME тип файла файла')),
                ('format', isc_common.fields.name_field.NameField(blank=True, null=True, verbose_name='Формат файла')),
                ('date', models.DateTimeField(db_index=True, verbose_name='Дата')),
                ('date_sign', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата подписания')),
            ],
            options={
                'verbose_name': 'Документы',
                'db_table': 'sales_dogovors_view',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Precent_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('code', isc_common.fields.code_field.CodeField(blank=True, null=True)),
                ('isFolder', models.BooleanField()),
                ('description', isc_common.fields.description_field.DescriptionField()),
                ('date', models.DateTimeField(db_index=True, verbose_name='Дата')),
                ('date_sign', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата подписания')),
                ('size', models.BigIntegerField(default=0, verbose_name='Размер фала')),
                ('real_name', models.TextField(blank=True, default=None, null=True, verbose_name='Первоначальное имя файла')),
                ('mime_type', isc_common.fields.name_field.NameField(blank=True, default=None, null=True, verbose_name='MIME тип файла файла')),
                ('format', isc_common.fields.name_field.NameField(blank=True, null=True, verbose_name='Формат файла')),
            ],
            options={
                'verbose_name': 'Документы',
                'db_table': 'sales_precent_view',
                'managed': False,
            },
        ),
    ]
