# Generated by Django 2.2.1 on 2019-05-16 16:28

from django.db import migrations, models
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0042_rec_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='status',
            name='id_owner',
            field=models.PositiveIntegerField(default=None),
        ),
        migrations.AddField(
            model_name='status',
            name='code_owner',
            field=isc_common.fields.code_field.CodeField(),
        ),
        migrations.AddField(
            model_name='status',
            name='name_owner',
            field=isc_common.fields.code_field.CodeField(),
        ),
        migrations.AlterField(
            model_name='status',
            name='code',
            field=isc_common.fields.code_field.CodeField(),
        ),
        migrations.AlterUniqueTogether(
            name='status',
            unique_together={('code', 'code_owner')},
        ),
    ]
