# Generated by Django 2.2.1 on 2019-05-30 12:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0043_auto_20190530_1205'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations',
            name='end',
            field=models.DateTimeField(blank=True, db_index=True, null=True),
        ),
    ]
