# Generated by Django 3.0.3 on 2020-02-16 20:13

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0185_auto_20200216_2008'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ready_2_launch_detail',
            name='ready',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='production.Ready_2_launch'),
        ),
    ]
