# Generated by Django 2.2.8 on 2019-12-06 08:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Operation_types',
        ),
    ]
