# Generated by Django 2.2.7 on 2019-11-17 04:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0111_launch_item_line'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launch_item_refs',
            name='child',
        ),
        migrations.RemoveField(
            model_name='launch_item_refs',
            name='item_refs',
        ),
        migrations.RemoveField(
            model_name='launch_item_refs',
            name='parent',
        ),
        migrations.RemoveField(
            model_name='launch_items',
            name='item',
        ),
        migrations.RemoveField(
            model_name='launch_items',
            name='launch',
        ),
        migrations.RemoveField(
            model_name='launches',
            name='demand',
        ),
        migrations.RemoveField(
            model_name='launches',
            name='parent',
        ),
        migrations.RemoveField(
            model_name='launches',
            name='status',
        ),
        migrations.DeleteModel(
            name='Launch_item_line',
        ),
        migrations.DeleteModel(
            name='Launch_item_refs',
        ),
        migrations.DeleteModel(
            name='Launch_items',
        ),
        migrations.DeleteModel(
            name='Launches',
        ),
    ]
