# Generated by Django 2.2.3 on 2019-07-09 21:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0055_auto_20190709_2116'),
    ]

    operations = [
        migrations.AddField(
            model_name='uploades',
            name='log',
            field=models.TextField(blank=True, null=True),
        ),
    ]
