# Generated by Django 3.0.2 on 2020-01-20 15:15

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0168_auto_20200120_1028'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_def_resources',
            name='props',
            field=bitfield.models.BitField((('rec_default', 'Записать ресурс по умолчанию на все операции на которых нет ресурсов'),), db_index=True, default=0),
        ),
    ]
