# Generated by Django 2.2.1 on 2019-05-22 17:51

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0023_auto_20190522_1750'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_plan_template_items',
            name='item',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='operation_plan_template_items',
            name='operation_plan_templates',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operation_plan_templates'),
        ),
        migrations.AlterField(
            model_name='operation_plan_template_items',
            name='qty',
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterField(
            model_name='operation_plan_templates_item_lines',
            name='operation_plan_template_item',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operation_plan_template_items'),
        ),
    ]
