# Generated by Django 3.0.3 on 2020-02-08 14:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0203_auto_20200208_1408'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='material_askon',
            unique_together=set(),
        ),
    ]
