# Generated by Django 2.2 on 2019-04-25 11:46

from django.db import migrations
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0038_auto_20190425_0829'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='STMP_2',
            field=isc_common.fields.name_field.NameField(verbose_name='Обозначение изделия'),
        ),
    ]
