# Generated by Django 3.0.3 on 2020-02-17 10:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0187_remove_ready_2_launch_detail_mat_view_name'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='resource',
            name='parent',
        ),
    ]
