# Generated by Django 2.2.6 on 2019-10-28 14:05

import django.utils.timezone
from django.db import migrations, models

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0095_auto_20191025_1311'),
        ('ckk', '0158_delete_status'),
        ('production', '0078_auto_20191022_0853'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations_item',
            name='item',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Item'),
        ),
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('item', 'num')},
        ),
        migrations.CreateModel(
            name='Ready_2_launch',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('notes', models.TextField(blank=True, null=True)),
                ('demand', isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='sales.Demand')),
            ],
            options={
                'verbose_name': 'Готовность к запуску',
            },
        ),
        migrations.RemoveField(
            model_name='operations_item',
            name='prod_item',
        ),
    ]
