# Generated by Django 2.2 on 2019-04-14 08:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0013_auto_20190414_0758'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='document_attrs',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='documents',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='documents_thumb',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='documents_thumb10',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='pathes',
            name='deleted_at',
        ),
    ]
