# Generated by Django 2.2 on 2019-04-26 09:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0010_operation_plan_template_locations_item_line'),
    ]

    operations = [
        migrations.CreateModel(
            name='TempProductionOperationsplan',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('qty', models.PositiveIntegerField()),
            ],
            options={
                'verbose_name': 'Временная таблица',
                'db_table': 'temp_production_operationsplan',
                'managed': False,
            },
        ),
    ]
