# Generated by Django 2.2 on 2019-04-18 11:03

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0030_locations'),
    ]

    operations = [
        migrations.AddField(
            model_name='locations',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
    ]
