# Generated by Django 2.2.8 on 2019-12-06 09:23

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0021_auto_20191206_0855'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_types',
            name='props',
            field=bitfield.models.BitField((('isoper', 'Является операцией'), ('plus', 'Приходная операция'), ('minus', 'Приходная операция')), db_index=True, default=0),
        ),
    ]
