# Generated by Django 2.2.1 on 2019-05-22 12:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0020_operation_material'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='operation_plan_templates',
            options={'verbose_name': 'Шаблоны заданий в производство'},
        ),
        migrations.RemoveField(
            model_name='operation_plan_templates',
            name='name',
        ),
        migrations.AddField(
            model_name='operation_plan_templates',
            name='qty',
            field=models.PositiveIntegerField(default=None),
        ),
    ]
