# Generated by Django 2.2.3 on 2019-07-07 07:28

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        # ('one_c', '0015_delete_uuid_2_id'),
        ('ckk', '0126_remove_materials_material_1c'),
    ]

    operations = [
        migrations.AddField(
            model_name='materials',
            name='nomenklatura_1C',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='one_c.Document_1c'),
        ),
    ]
