# Generated by Django 3.0.2 on 2020-01-15 09:59

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0123_pathes_attr_type'),
        ('ckk', '0181_auto_20191217_1331'),
    ]

    operations = [
        migrations.AddField(
            model_name='item_line',
            name='Документ_на_материал',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Документ_на_материал_Item_line', to='kd.Document_attributes'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='Документ_на_сортамент',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Документ_на_сортамент_Item_line', to='kd.Document_attributes'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='Наименование_материала',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Наименование_материала_Item_line', to='kd.Document_attributes'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='Наименование_сортамента',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Наименование_сортамента_Item_line', to='kd.Document_attributes'),
        ),
    ]
