# Generated by Django 3.0.3 on 2020-02-08 14:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0172_auto_20200208_1429'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='operations_item',
            constraint=models.UniqueConstraint(condition=models.Q(num=None), fields=('item', 'operation'), name='Operations_item_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='operations_item',
            constraint=models.UniqueConstraint(fields=('item', 'num', 'operation'), name='Operations_item_unique_constraint_1'),
        ),
    ]
