# Generated by Django 2.2.7 on 2019-11-20 14:41

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0125_auto_20191119_1843'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_line',
            name='added_parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_added_parent', to='production.Launch_item_line'),
        ),
    ]
