# Generated by Django 2.2.4 on 2019-08-20 18:57

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0146_material_askon_mview'),
        ('production', '0055_remove_operation_material_material'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_material',
            name='material',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Material_askon'),
        ),
    ]
