# Generated by Django 3.0.3 on 2020-02-08 11:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0200_auto_20200208_0741'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='item_refs',
            name='Item_refs_not_circulate_refs',
        ),
        migrations.AlterUniqueTogether(
            name='item_refs',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_type_id', None), ('version', None)), fields=('props',), name='Item_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'props'), name='Item_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_2', 'props'), name='Item_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'STMP_2', 'props'), name='Item_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_type_id', None)), fields=('props', 'version'), name='Item_unique_constraint_4'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_type_id', None)), fields=('STMP_1', 'props', 'version'), name='Item_unique_constraint_5'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_type_id', None)), fields=('STMP_2', 'props', 'version'), name='Item_unique_constraint_6'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(lotsman_type_id=None), fields=('STMP_1', 'STMP_2', 'props', 'version'), name='Item_unique_constraint_7'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('version', None)), fields=('lotsman_type_id', 'props'), name='Item_unique_constraint_8'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('version', None)), fields=('STMP_1', 'lotsman_type_id', 'props'), name='Item_unique_constraint_9'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('version', None)), fields=('STMP_2', 'lotsman_type_id', 'props'), name='Item_unique_constraint_10'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(version=None), fields=('STMP_1', 'STMP_2', 'lotsman_type_id', 'props'), name='Item_unique_constraint_11'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None)), fields=('lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_12'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(STMP_2=None), fields=('STMP_1', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_13'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(STMP_1=None), fields=('STMP_2', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_14'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(fields=('STMP_1', 'STMP_2', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_15'),
        ),
        migrations.AddConstraint(
            model_name='item_refs',
            constraint=models.UniqueConstraint(fields=('child', 'parent'), name='Item_refs_unique_1'),
        ),
        migrations.AddConstraint(
            model_name='item_refs',
            constraint=models.UniqueConstraint(condition=models.Q(parent=None), fields=('child',), name='Item_refs_unique_2'),
        ),
    ]
