# Generated by Django 2.2 on 2019-04-26 10:03

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0012_auto_20190426_1001'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operationsplan',
            name='status',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Status'),
        ),
        migrations.DeleteModel(
            name='Operation_plan_status',
        ),
    ]
