# Generated by Django 3.0.3 on 2020-02-19 03:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0099_auto_20200219_0316'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Operation_locations',
        ),
    ]
