# Generated by Django 2.1.7 on 2019-03-28 10:18

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0003_auto_20190327_1141'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attrs',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'),), blank=True, default=1, null=True),
        ),
    ]
