# Generated by Django 3.0.2 on 2020-01-31 11:21

from django.db import migrations, models
import django.db.models.expressions


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0126_remove_lotsman_documents_hierarcy_path'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.CheckConstraint(check=models.Q(_negated=True, child=django.db.models.expressions.F('parent')), name='Lotsman_documents_hierarcy_not_circulate_refs'),
        ),
    ]
