# Generated by Django 2.2.6 on 2019-10-22 08:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0077_delete_operations_refs'),
    ]

    operations = [
        migrations.RenameField(
            model_name='item_refs',
            old_name='item',
            new_name='item_refs',
        ),
        migrations.AlterUniqueTogether(
            name='item_refs',
            unique_together={('item_refs', 'child', 'parent')},
        ),
    ]
