# Generated by Django 2.2.3 on 2019-07-28 19:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0074_auto_20190728_1924'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pathes',
            name='attr_type',
        ),
    ]
