# Generated by Django 3.0.2 on 2020-01-21 22:31

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('planing', '0078_auto_20200121_2231'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations',
            name='creator',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='operations',
            name='date',
            field=models.DateTimeField(),
        ),
    ]
