# Generated by Django 3.0.3 on 2020-02-10 08:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0206_auto_20200209_1230'),
        ('production', '0176_auto_20200209_1207'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='operations_item',
            name='Operations_item_unique_constraint_0',
        ),
        migrations.RemoveConstraint(
            model_name='operations_item',
            name='Operations_item_unique_constraint_1',
        ),
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('item', 'operation')},
        ),
    ]
