# Generated by Django 3.0.3 on 2020-02-09 12:07

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('production', '0175_auto_20200209_1152'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='resource_users',
            unique_together={('resource', 'user')},
        ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(condition=models.Q(calendar=None), fields=('location',), name='Resource_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(fields=('calendar', 'location'), name='Resource_unique_constraint_1'),
        ),
    ]
