# Generated by Django 2.2 on 2019-04-16 10:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0021_auto_20190415_1307'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2', 'props')},
        ),
    ]
