# Generated by Django 2.2.8 on 2019-12-04 11:17

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0070_auto_20190829_1017'),
        ('ckk', '0161_auto_20191122_0920'),
    ]

    operations = [
        migrations.AddField(
            model_name='locations',
            name='calendar',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='clndr.Calendars'),
        ),
    ]
