# Generated by Django 3.0.3 on 2020-03-02 03:21

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0141_auto_20200222_1755'),
        ('production', '0224_auto_20200229_1523'),
    ]

    operations = [
        migrations.AddField(
            model_name='launch_item_line',
            name='SPC_CLM_COUNT_PER_ONE',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Launch_SPC_CLM_COUNT_PER_ONE', to='kd.Document_attributes', verbose_name='Количество на еденицу'),
        ),
    ]
