# Generated by Django 3.0.3 on 2020-02-26 10:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0209_auto_20200226_0828'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_operation_resources',
            name='batch_size',
            field=models.PositiveIntegerField(db_index=True, default=1),
        ),
        migrations.AlterField(
            model_name='launch_operations_item',
            name='num',
            field=models.PositiveIntegerField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='launch_operations_item',
            name='qty',
            field=models.PositiveIntegerField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='launch_operations_material',
            name='qty',
            field=models.FloatField(db_index=True),
        ),
    ]
