# Generated by Django 2.2 on 2019-04-21 13:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0021_documents_view'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='pathes',
            table='pathes',
        ),
    ]
