# Generated by Django 2.2.1 on 2019-05-21 19:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0052_merge_20190521_1855'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='status',
            unique_together={('code_owner', 'code')},
        ),
    ]
