# Generated by Django 2.2.8 on 2019-12-04 16:07

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0141_resource_users'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource_users',
            name='props',
            field=bitfield.models.BitField((('compulsory_reading', 'Обязательное прочтение'),), db_index=True, default=1),
        ),
    ]
