# Generated by Django 2.2.2 on 2019-06-13 16:07

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0099_auto_20190613_1607'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_line',
            name='child',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, related_name='item_child', to='ckk.Item', verbose_name='Товарная позиция'),
        ),
    ]
