# Generated by Django 2.2.1 on 2019-05-28 15:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0026_auto_20190524_1200'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Operation_plan_template_locations',
        ),
    ]
