# Generated by Django 2.2.1 on 2019-05-30 13:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0046_operations_parent'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operations',
            name='end',
        ),
        migrations.RemoveField(
            model_name='operations',
            name='start',
        ),
    ]
