# Generated by Django 3.0.3 on 2020-02-17 12:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0188_remove_resource_parent'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launch_item_refs',
            name='added_launch',
        ),
        migrations.RemoveField(
            model_name='launch_item_refs',
            name='description',
        ),
    ]
