# Generated by Django 2.2.4 on 2019-08-21 06:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0057_auto_20190820_1858'),
    ]

    operations = [
        migrations.RenameField(
            model_name='operation_material',
            old_name='material',
            new_name='material_askon',
        ),
    ]
