# Generated by Django 3.0.3 on 2020-02-23 15:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0203_launch_item_refs_qty'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs',
            name='qty',
            field=models.DecimalField(blank=True, decimal_places=4, default=0.0, max_digits=19, null=True),
        ),
    ]
