# Generated by Django 2.2.8 on 2019-12-21 04:46

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0181_auto_20191217_1331'),
        ('kd', '0122_remove_lotsman_document_attr_cross_position_in_document'),
    ]

    operations = [
        migrations.AddField(
            model_name='pathes',
            name='attr_type',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Attr_type', verbose_name='Атрибут'),
        ),
    ]
