# Generated by Django 2.2.7 on 2019-11-17 11:27

import django.utils.timezone
from django.db import migrations, models

import isc_common.fields.description_field
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0089_auto_20191117_1110'),
    ]

    operations = [
        migrations.CreateModel(
            name='Launch_operations_item',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('qty', models.PositiveIntegerField(blank=True, default=None, null=True)),
                ('num', models.PositiveIntegerField(blank=True, default=None, null=True)),
                ('description', isc_common.fields.description_field.DescriptionField()),
                ('ed_izm', isc_common.fields.related.ForeignKeyProtect(blank=True, default=None, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm')),
                ('item', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Item')),
                ('operation', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operations')),
                ('operationitem', isc_common.fields.related.ForeignKeySetNull(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='production.Operations_item')),
                ('parent', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Launch_operations_item')),
            ],
            options={
                'verbose_name': 'Кросс таблица',
                'unique_together': {('item', 'num')},
            },
        ),
    ]
