# Generated by Django 2.2.8 on 2019-12-07 18:10

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0159_auto_20191207_1801'),
        ('planing', '0039_auto_20191207_1802'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_launch_operation_material',
            name='edizm',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operation_material',
            name='material',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operation_material',
            name='material_askon',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operation_material',
            name='qty',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operation_resources',
            name='location',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operation_resources',
            name='resource',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operations_item',
            name='ed_izm',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operations_item',
            name='num',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operations_item',
            name='qty',
        ),
        migrations.AddField(
            model_name='operation_launch_operation_material',
            name='launch_operation_material',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='production.Launch_operations_material'),
        ),
        migrations.AddField(
            model_name='operation_launch_operation_resources',
            name='launch_operation_resources',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='production.Launch_operation_resources'),
        ),
        migrations.AddField(
            model_name='operation_launch_operations_item',
            name='launch_operations_item',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='production.Launch_operations_item'),
        ),
    ]
