# Generated by Django 2.2.2 on 2019-06-26 09:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0110_auto_20190624_1357'),
    ]

    operations = [
        migrations.CreateModel(
            name='Item_line_view',
            fields=[
            ],
            options={
                'verbose_name': 'Строка состава изделия',
                'db_table': 'ckk_item_line_view',
                'managed': False,
                'proxy': True,
            },
            bases=('ckk.item_line',),
        ),
    ]
