# Generated by Django 2.2.2 on 2019-06-10 09:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0045_auto_20190610_0109'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='document_attr_cross',
            unique_together={('document', 'position_in_document')},
        ),
    ]
