# Generated by Django 2.2.4 on 2019-08-20 12:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0008_auto_20190820_1235'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user_add_info',
            name='ip',
            field=models.GenericIPAddressField(blank=True, null=True),
        ),
    ]
