# Generated by Django 3.0.3 on 2020-02-29 05:32

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0114_auto_20200228_1240'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_level',
            name='props',
            field=bitfield.models.BitField((('isProductionOrder', 'Уровень заказа на производство'),), db_index=True, default=0),
        ),
    ]
