# Generated by Django 2.2 on 2019-04-14 16:16

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0017_auto_20190414_0923'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Item_line_refs',
            new_name='Item_refs',
        ),
        migrations.AlterModelOptions(
            name='item_refs',
            options={'verbose_name': 'Item_refs'},
        ),
        migrations.AlterField(
            model_name='item_line',
            name='isFolder',
            field=models.BooleanField(default=False, verbose_name='Признак наличия потомков'),
        ),
        migrations.AlterField(
            model_name='item_refs',
            name='child',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='child', to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='item_refs',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='parent', to='ckk.Item'),
        ),
    ]
