# Generated by Django 2.2.6 on 2019-10-10 15:00

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0152_remove_status_code_owner'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('from_cdw', 'Получено из чертежа'), ('from_spw', 'Получено из спецификации'), ('for_line', 'Строка спецификации'), ('from_pdf', 'Получено из бумажного архива'), ('man_input', 'Занесено вручную'), ('copied', 'Скопировано')), db_index=True, default=1),
        ),
    ]
