# Generated by Django 2.2.2 on 2019-06-10 01:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0043_auto_20190610_0056'),
    ]

    operations = [
        migrations.AddField(
            model_name='document_attr_cross',
            name='position_in_document',
            field=models.PositiveIntegerField(default=None),
        ),
    ]
