# Generated by Django 2.2.8 on 2019-12-14 10:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0100_lotsman_document_attr_cross_lotsman_documents_hierarcy'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lotsman_documents_hierarcy',
            name='id',
            field=models.BigIntegerField(primary_key=True, serialize=False),
        ),
    ]
