# Generated by Django 2.2.1 on 2019-05-22 08:37

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0018_auto_20190522_0748'),
    ]

    operations = [
        migrations.AddField(
            model_name='precent',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='document', to='sales.Precent'),
        ),
        migrations.AlterField(
            model_name='precent',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='parent', to='sales.Precent'),
        ),
    ]
