# Generated by Django 3.0.2 on 2020-01-22 07:52

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0034_standard_colors_color'),
        ('accounting', '0009_remove_tmp_buffer_color'),
    ]

    operations = [
        migrations.AddField(
            model_name='tmp_buffer',
            name='color',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='isc_common.Standard_colors'),
        ),
    ]
