# Generated by Django 2.2.5 on 2019-09-17 19:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0053_auto_20190917_1855'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Demand',
        ),
    ]
