# Generated by Django 2.2.1 on 2019-05-24 10:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0024_auto_20190522_1751'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='materials',
            name='parent',
        ),
    ]
