# Generated by Django 2.2.8 on 2019-12-12 20:39

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0171_item_refs_syntetic_parent'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_refs',
            name='syntetic_child',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='syntetic_child', to='ckk.Item', unique=True),
        ),
    ]
