# Generated by Django 2.2.1 on 2019-05-28 22:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0027_delete_operation_plan_template_locations'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_plan_templates',
            name='parent',
        ),
        migrations.RemoveField(
            model_name='operation_plan_templates_item_lines',
            name='item_line',
        ),
        migrations.RemoveField(
            model_name='operation_plan_templates_item_lines',
            name='operation_plan_template_item',
        ),
        migrations.DeleteModel(
            name='Operation_plan_template_items',
        ),
        migrations.DeleteModel(
            name='Operation_plan_templates',
        ),
        migrations.DeleteModel(
            name='Operation_plan_templates_item_lines',
        ),
    ]
