# Generated by Django 2.2.7 on 2019-11-17 17:58

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0096_auto_20191117_1758'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_line',
            name='launch',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Launches'),
        ),
        migrations.AlterField(
            model_name='launch_item_refs',
            name='launch',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Launches'),
        ),
    ]
