# Generated by Django 2.2.8 on 2019-12-06 12:49

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0025_auto_20191206_1151'),
        ('production', '0151_operations_planing_operation'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operations',
            name='planing_operation',
        ),
        migrations.AddField(
            model_name='operations',
            name='planing_operation_type',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planing_operation_type', to='planing.Operation_types'),
        ),
    ]
