# Generated by Django 2.2.4 on 2019-08-20 18:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0054_operations_view_resource_view'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_material',
            name='material',
        ),
    ]
