# Generated by Django 3.0.3 on 2020-02-22 11:31

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0195_remove_launches_facets'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations',
            name='props',
            field=bitfield.models.BitField((('assemle', 'Операция комплектации'),), db_index=True, default=0),
        ),
    ]
