# Generated by Django 2.2.7 on 2019-11-21 13:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0016_launch_item_timing_view'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='launch_item_timing_view',
            table='planing_launch_item_timing_view',
        ),
    ]
