# Generated by Django 2.2.8 on 2019-12-16 07:58

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0114_auto_20191215_2048'),
    ]

    operations = [
        migrations.AddField(
            model_name='lotsman_documents_hierarcy',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('beenItemed', 'Был внесен в состав изделий')), db_index=True, default=1),
        ),
    ]
