# Generated by Django 2.2.6 on 2019-10-08 12:53

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0152_remove_status_code_owner'),
        ('production', '0067_auto_20191008_0937'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_material',
            name='operation',
        ),
        migrations.RemoveField(
            model_name='operation_resources',
            name='operation',
        ),
        migrations.AddField(
            model_name='operation_resources',
            name='location',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
        migrations.AlterField(
            model_name='operation_resources',
            name='resource',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Resource'),
        ),
    ]
