# Generated by Django 2.2.2 on 2019-06-11 11:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0093_auto_20190611_1154'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='cdw_pdf_item_view',
            table='ckk_cdw_pdf_item_view',
        ),
    ]
