# Generated by Django 3.0.3 on 2020-02-10 12:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0207_auto_20200210_1248'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='materials',
            constraint=models.UniqueConstraint(condition=models.Q(('name', None), ('nomenklatura_model', None)), fields=('gost', 'location', 'materials_type'), name='Materials_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='materials',
            constraint=models.UniqueConstraint(condition=models.Q(nomenklatura_model=None), fields=('gost', 'location', 'materials_type', 'name'), name='Materials_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='materials',
            constraint=models.UniqueConstraint(condition=models.Q(name=None), fields=('gost', 'location', 'materials_type', 'nomenklatura_model'), name='Materials_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='materials',
            constraint=models.UniqueConstraint(fields=('gost', 'location', 'materials_type', 'name', 'nomenklatura_model'), name='Materials_unique_constraint_3'),
        ),
    ]
