# Generated by Django 3.0.3 on 2020-02-17 13:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0094_auto_20200217_1323'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_item',
            name='item_full_name',
            field=models.TextField(),
        ),
    ]
