# Generated by Django 3.0.3 on 2020-02-08 07:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0196_auto_20200208_0736'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='item',
            name='unique_with_optional',
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('version', None)), fields=('STMP_1', 'STMP_2', 'version', 'lotsman_type_id'), name='unique_with_optional'),
        ),
    ]
