# Generated by Django 2.2 on 2019-04-14 04:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0010_auto_20190414_0429'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='documents_thumb10',
            managers=[
            ],
        ),
    ]
