# Generated by Django 2.2.2 on 2019-06-09 22:49

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0084_auto_20190608_1341'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'),), db_index=True, default=1),
        ),
    ]
