# Generated by Django 2.2.7 on 2019-11-21 06:23

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0159_auto_20191119_2034'),
        ('planing', '0012_auto_20191121_0605'),
    ]

    operations = [
        migrations.RenameField(
            model_name='launch_item_refs_timing',
            old_name='qty',
            new_name='time_duration_operations',
        ),
        migrations.AddField(
            model_name='launch_item_refs_timing',
            name='ed_izm',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, to='ckk.Ed_izm'),
        ),
    ]
