# Generated by Django 2.2.1 on 2019-05-17 16:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0012_auto_20190517_1248'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='customer',
            options={'verbose_name': 'Клиент'},
        ),
    ]
