# Generated by Django 2.2.3 on 2019-07-09 10:32

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0130_remove_materials_ed_izm'),
        ('production', '0051_auto_20190616_0635'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_material',
            name='ed_izm',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AddField(
            model_name='operation_material',
            name='qty',
            field=models.DecimalField(decimal_places=4, default=0.0, max_digits=10),
        ),
        migrations.CreateModel(
            name='Operations_item',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('qty', models.PositiveIntegerField(default=None)),
                ('ed_izm', isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm')),
                ('item', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Item')),
                ('operation', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operations')),
                ('parent', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Operations_item')),
            ],
            options={
                'verbose_name': 'Кросс таблица',
            },
        ),
    ]
