# Generated by Django 2.2.1 on 2019-05-18 17:03

from django.db import migrations
import isc_common.fields.files


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0025_auto_20190517_2112'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documents_thumb',
            name='attfile',
            field=isc_common.fields.files.FileFieldEx(blank=True, default=None, max_length=255, null=True, upload_to='', verbose_name='Файл'),
        ),
        migrations.AlterField(
            model_name='documents_thumb10',
            name='attfile',
            field=isc_common.fields.files.FileFieldEx(blank=True, default=None, max_length=255, null=True, upload_to='', verbose_name='Файл'),
        ),
    ]
