# Generated by Django 2.2.8 on 2019-12-04 09:19

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0017_auto_20191121_1331'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs_timing',
            name='ed_izm',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
    ]
