# Generated by Django 3.0.3 on 2020-02-17 09:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0091_auto_20200217_0905'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='operation_level',
            options={'verbose_name': 'Кросс-таблица'},
        ),
        migrations.AlterField(
            model_name='levels',
            name='code',
            field=models.PositiveIntegerField(default=0),
        ),
    ]
