# Generated by Django 2.2.1 on 2019-05-17 12:48

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0010_demand'),
    ]

    operations = [
        migrations.AddField(
            model_name='demand',
            name='precent',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent'),
        ),
    ]
