# Generated by Django 2.2.6 on 2019-10-08 07:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0152_remove_status_code_owner'),
        ('production', '0065_operations_item_num'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('item', 'operation', 'num')},
        ),
    ]
