# Generated by Django 3.0.2 on 2020-01-18 14:36

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0059_auto_20200117_1859'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_types',
            name='props',
            field=bitfield.models.BitField((('plus', 'Приходная операция'), ('minus', 'Расходная операция')), db_index=True, default=0),
        ),
    ]
