# Generated by Django 2.2.2 on 2019-06-10 18:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0088_auto_20190610_1000'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item_line',
            unique_together={('parent', 'child')},
        ),
    ]
