# Generated by Django 3.0.3 on 2020-02-17 09:05

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0089_levels'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_level',
            name='level',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, related_name='planing_lev_1', to='planing.Levels'),
        ),
        migrations.AlterField(
            model_name='operation_level',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='planing_operation_1', to='planing.Operations'),
        ),
    ]
