# Generated by Django 3.0.3 on 2020-02-09 12:44

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0035_auditmodelex'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ckk', '0206_auto_20200209_1230'),
        ('production', '0176_auto_20200209_1207'),
        ('planing', '0086_auto_20200208_1424'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operation_color',
            unique_together={('operation', 'color')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_executor',
            unique_together={('operation', 'executor')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_item',
            unique_together={('operation', 'item')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_launches',
            unique_together={('operation', 'launch')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_level',
            unique_together={('operation', 'level')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_locations',
            unique_together={('operation', 'location')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_material',
            unique_together={('operation', 'material')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_resources',
            unique_together={('operation', 'resource')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_standard_prod',
            unique_together={('operation', 'material')},
        ),
        migrations.AlterUniqueTogether(
            name='operation_types_users',
            unique_together={('operation_type', 'user')},
        ),
    ]
