# Generated by Django 2.2.1 on 2019-05-29 13:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0036_operation_material'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_resources',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='operation_resources',
            name='deliting',
        ),
        migrations.RemoveField(
            model_name='operation_resources',
            name='editing',
        ),
        migrations.RemoveField(
            model_name='operation_resources',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='operation_resources',
            name='lastmodified',
        ),
        migrations.AlterField(
            model_name='operation_resources',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
