# Generated by Django 3.0.3 on 2020-02-24 14:48

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0111_auto_20200224_0413'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_refs',
            name='props',
            field=bitfield.models.BitField((('inner_routing', 'Связь операций внутри товарной позиции'), ('outer_routing', 'Связь операций между товарными позициями'), ('product_order_routing', 'Связи в блоке заказы на производство')), db_index=True, default=0),
        ),
    ]
