# Generated by Django 2.2.4 on 2019-08-08 12:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0138_material_type_view'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='version',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
