# Generated by Django 2.2.6 on 2019-10-29 18:42

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0107_auto_20191029_1437'),
    ]

    operations = [
        migrations.AlterField(
            model_name='precent',
            name='precent_item_type',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent_item_types'),
        ),
        migrations.AlterField(
            model_name='precent',
            name='precent_type',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent_types'),
        ),
    ]
