# Generated by Django 2.2.3 on 2019-07-20 07:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0135_auto_20190719_1925'),
        ('kd', '0067_auto_20190720_0729'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='document_attributes',
            unique_together={('value_str', 'attr_type')},
        ),
    ]
