# Generated by Django 3.0.2 on 2020-01-21 20:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounting', '0006_tmp_buffer_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='tmp_buffer',
            name='value_off',
            field=models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True),
        ),
    ]
