# Generated by Django 2.2.7 on 2019-11-17 13:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0092_launch_operation_resources'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Launch_item_refs',
        ),
    ]
