# Generated by Django 2.2.1 on 2019-05-28 17:09

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0040_precent_locations'),
    ]

    operations = [
        migrations.CreateModel(
            name='Precent_items_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('qty', models.PositiveIntegerField()),
            ],
            options={
                'verbose_name': 'Комплектация распоряжения',
                'db_table': 'sales_precent_items_view',
                'managed': False,
            },
        ),
        migrations.AlterField(
            model_name='precent',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent'),
        ),
    ]
