# Generated by Django 3.0.2 on 2020-01-20 10:28

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0185_auto_20200117_1305'),
        ('production', '0167_auto_20200120_1025'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations_item',
            name='item',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Item'),
        ),
    ]
