# Generated by Django 2.2.6 on 2019-10-20 19:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0008_prod_tasks'),
    ]

    operations = [
        migrations.AlterField(
            model_name='prod_tasks',
            name='create_date',
            field=models.DateTimeField(verbose_name='Дата'),
        ),
    ]
