# Generated by Django 2.2.8 on 2019-12-13 12:52

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0177_item_refs_hierarcy'),
        ('kd', '0087_auto_20191213_1243'),
    ]

    operations = [
        migrations.AddField(
            model_name='lotsman_documents',
            name='attr_type',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Attr_type', verbose_name='Тип атрибута'),
        ),
        migrations.AddField(
            model_name='lotsman_documents',
            name='value_int',
            field=models.BigIntegerField(blank=True, db_index=True, null=True, verbose_name='Значение атрибута'),
        ),
        migrations.AddField(
            model_name='lotsman_documents',
            name='value_str',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Значение атрибута'),
        ),
    ]
