# Generated by Django 2.2 on 2019-04-25 17:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0002_auto_20190425_1705'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_plan_template_locations',
            name='distribution_coefficient',
            field=models.IntegerField(default=1, verbose_name='коэффициент распределения'),
        ),
    ]
