# Generated by Django 2.2 on 2019-04-17 15:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0019_auto_20190415_1307'),
    ]

    operations = [
        migrations.CreateModel(
            name='Cdw_attrs',
            fields=[
            ],
            options={
                'verbose_name': 'Чертеж',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('kd.document_attrs',),
        ),
        migrations.CreateModel(
            name='Spw_attrs',
            fields=[
            ],
            options={
                'verbose_name': 'Аттрибуты Спецификаций',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('kd.document_attrs',),
        ),
    ]
