# Generated by Django 2.2.2 on 2019-06-07 19:23

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0082_auto_20190607_1922'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_line',
            name='STMP_1',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_NAME', to='kd.Document_attributes', verbose_name='Наименование'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='STMP_2',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_MARK', to='kd.Document_attributes', verbose_name='Обозначение'),
        ),
    ]
