# Generated by Django 3.0.5 on 2020-04-13 14:54

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0221_item_qty'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_qty',
            name='props',
            field=bitfield.models.BitField((('items', 'Состав изделия (Технологическая спецификация)'), ('teach', 'Производственная спецификация')), db_index=True, default=1),
        ),
    ]
