# Generated by Django 2.2.8 on 2019-12-14 15:37

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0103_auto_20191214_1434'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attr_cross',
            name='attribute',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Document_attributes'),
        ),
        migrations.AlterField(
            model_name='lotsman_document_attr_cross',
            name='attribute',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Document_attributes'),
        ),
    ]
