# Generated by Django 2.2.5 on 2019-09-18 14:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0055_auto_20190918_1437'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='precent',
            name='customer',
        ),
        migrations.RemoveField(
            model_name='precent',
            name='type',
        ),
    ]
