# Generated by Django 2.2.3 on 2019-07-04 21:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0124_auto_20190703_2206'),
    ]

    operations = [
        migrations.AddField(
            model_name='material_params',
            name='order',
            field=models.PositiveIntegerField(default=0),
        ),
    ]
