# Generated by Django 2.2.8 on 2019-12-06 11:51

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0024_auto_20191206_1151'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations',
            name='opertype',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='planing.Operation_types'),
        ),
        migrations.AlterField(
            model_name='operations',
            name='value',
            field=models.DecimalField(decimal_places=4, max_digits=19),
        ),
    ]
