# Generated by Django 2.2.1 on 2019-05-17 16:41

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0015_auto_20190426_1401'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operationsplan',
            name='startdate',
            field=models.DateTimeField(db_index=True, default=django.utils.timezone.now, verbose_name='Дата начала'),
        ),
        migrations.DeleteModel(
            name='Temp_production_operationsplan',
        ),
    ]
