# Generated by Django 2.2.2 on 2019-06-29 12:56

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0052_pathes_props'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documents_thumb',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='КД'),
        ),
        migrations.AlterField(
            model_name='documents_thumb10',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='КД'),
        ),
    ]
