# Generated by Django 2.2 on 2019-04-19 00:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0021_documents_view'),
        ('ckk', '0032_item_location'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item_image_refs',
            unique_together={('item', 'thumb10'), ('item', 'thumb')},
        ),
    ]
