# Generated by Django 2.2.6 on 2019-10-08 09:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0152_remove_status_code_owner'),
        ('production', '0066_auto_20191008_0731'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('item', 'num')},
        ),
    ]
