# Generated by Django 2.2.7 on 2019-11-19 14:50

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0121_auto_20191119_1418'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_operations_material',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'), ('added', 'Добавлено в данную производственную спецификацию'), ('edited', 'Изменено в данной производственной спецификации'), ('refreshed', 'Удалено из данной производственной спецификации')), db_index=True, default=1),
        ),
    ]
