# Generated by Django 2.2.3 on 2019-07-07 20:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0127_materials_nomenklatura_1c'),
    ]

    operations = [
        migrations.RenameField(
            model_name='materials',
            old_name='nomenklatura_1C',
            new_name='nomenklatura_model',
        ),
    ]
