# Generated by Django 2.2.2 on 2019-06-08 13:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0037_document_attrs_view'),
        ('ckk', '0083_auto_20190607_1923'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2', 'props')},
        ),
    ]
