# Generated by Django 3.0.2 on 2020-01-17 16:00

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0164_auto_20191225_1105'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launches',
            name='props',
            field=bitfield.models.BitField((('routing_made', 'Маршрутизация выполнена'),), db_index=True, default=0),
        ),
    ]
