# Generated by Django 2.2.6 on 2019-10-08 13:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0070_auto_20191008_1258'),
    ]

    operations = [
        migrations.RenameField(
            model_name='operation_material',
            old_name='operation_item',
            new_name='operationitem',
        ),
        migrations.RenameField(
            model_name='operation_resources',
            old_name='operation_item',
            new_name='operationitem',
        ),
    ]
