# Generated by Django 2.2.8 on 2019-12-02 12:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0122_auto_20191128_1229'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='tec_spc_item_refs',
            unique_together=None,
        ),
        migrations.RemoveField(
            model_name='tec_spc_item_refs',
            name='child',
        ),
        migrations.RemoveField(
            model_name='tec_spc_item_refs',
            name='item_refs',
        ),
        migrations.RemoveField(
            model_name='tec_spc_item_refs',
            name='parent',
        ),
        migrations.DeleteModel(
            name='Tec_spc_item_line',
        ),
        migrations.DeleteModel(
            name='Tec_spc_item_refs',
        ),
    ]
