# Generated by Django 2.2.7 on 2019-11-19 08:57

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0113_auto_20191119_0726'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_material',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Operation_material'),
        ),
    ]
