# Generated by Django 2.2.8 on 2019-12-08 10:01

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0052_auto_20191208_0959'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_refs',
            name='outcome',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='operation_outcome', to='planing.Operations'),
        ),
    ]
