# Generated by Django 2.2.1 on 2019-06-05 10:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0048_auto_20190605_1031'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operations_type',
            name='parent',
        ),
        migrations.RemoveField(
            model_name='operations',
            name='category',
        ),
        migrations.RemoveField(
            model_name='operations',
            name='type',
        ),
        migrations.DeleteModel(
            name='Operation_categories',
        ),
        migrations.DeleteModel(
            name='Operations_type',
        ),
    ]
