# Generated by Django 3.0.3 on 2020-02-08 16:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0204_auto_20200208_1413'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_0',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_1',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_2',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_3',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_4',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_5',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_6',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_7',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_8',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_9',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_10',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_11',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_12',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_13',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_14',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_15',
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_document_id', None), ('lotsman_type_id', None), ('version', None)), fields=('props',), name='Item_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_document_id', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'props'), name='Item_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_document_id', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_2', 'props'), name='Item_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_document_id', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'STMP_2', 'props'), name='Item_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_document_id', None), ('lotsman_type_id', None)), fields=('props', 'version'), name='Item_unique_constraint_4'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_document_id', None), ('lotsman_type_id', None)), fields=('STMP_1', 'props', 'version'), name='Item_unique_constraint_5'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_document_id', None), ('lotsman_type_id', None)), fields=('STMP_2', 'props', 'version'), name='Item_unique_constraint_6'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_document_id', None), ('lotsman_type_id', None)), fields=('STMP_1', 'STMP_2', 'props', 'version'), name='Item_unique_constraint_7'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_type_id', None), ('version', None)), fields=('lotsman_document_id', 'props'), name='Item_unique_constraint_8'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'lotsman_document_id', 'props'), name='Item_unique_constraint_9'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_2', 'lotsman_document_id', 'props'), name='Item_unique_constraint_10'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'STMP_2', 'lotsman_document_id', 'props'), name='Item_unique_constraint_11'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_type_id', None)), fields=('lotsman_document_id', 'props', 'version'), name='Item_unique_constraint_12'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_type_id', None)), fields=('STMP_1', 'lotsman_document_id', 'props', 'version'), name='Item_unique_constraint_13'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_type_id', None)), fields=('STMP_2', 'lotsman_document_id', 'props', 'version'), name='Item_unique_constraint_14'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(lotsman_type_id=None), fields=('STMP_1', 'STMP_2', 'lotsman_document_id', 'props', 'version'), name='Item_unique_constraint_15'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_document_id', None), ('version', None)), fields=('lotsman_type_id', 'props'), name='Item_unique_constraint_16'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_document_id', None), ('version', None)), fields=('STMP_1', 'lotsman_type_id', 'props'), name='Item_unique_constraint_17'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_document_id', None), ('version', None)), fields=('STMP_2', 'lotsman_type_id', 'props'), name='Item_unique_constraint_18'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_document_id', None), ('version', None)), fields=('STMP_1', 'STMP_2', 'lotsman_type_id', 'props'), name='Item_unique_constraint_19'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_document_id', None)), fields=('lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_20'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_document_id', None)), fields=('STMP_1', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_21'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_document_id', None)), fields=('STMP_2', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_22'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(lotsman_document_id=None), fields=('STMP_1', 'STMP_2', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_23'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('version', None)), fields=('lotsman_document_id', 'lotsman_type_id', 'props'), name='Item_unique_constraint_24'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('version', None)), fields=('STMP_1', 'lotsman_document_id', 'lotsman_type_id', 'props'), name='Item_unique_constraint_25'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('version', None)), fields=('STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props'), name='Item_unique_constraint_26'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(version=None), fields=('STMP_1', 'STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props'), name='Item_unique_constraint_27'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None)), fields=('lotsman_document_id', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_28'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(STMP_2=None), fields=('STMP_1', 'lotsman_document_id', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_29'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(STMP_1=None), fields=('STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_30'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(fields=('STMP_1', 'STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_31'),
        ),
    ]
