# Generated by Django 2.2.8 on 2019-12-14 14:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0102_auto_20191214_1433'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lotsman_documents_hierarcy',
            name='id_lotsman',
            field=models.BigIntegerField(db_index=True),
        ),
    ]
