# Generated by Django 2.2.1 on 2019-05-29 11:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0032_auto_20190529_1112'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations',
            name='end',
            field=models.DateTimeField(blank=True, db_index=True, default=None),
        ),
        migrations.AddField(
            model_name='operations',
            name='start',
            field=models.DateTimeField(blank=True, db_index=True, default=None),
        ),
    ]
