# Generated by Django 2.2.6 on 2019-10-29 07:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0102_auto_20191028_2134'),
    ]

    operations = [
        migrations.RenameField(
            model_name='precent',
            old_name='precent_type',
            new_name='precent_item_type',
        ),
    ]
