# Generated by Django 2.2.6 on 2019-10-23 10:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0086_auto_20191022_2224'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='demand',
            name='due_date',
        ),
    ]
