# Generated by Django 2.2.6 on 2019-10-14 09:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0155_item_operations_view'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='item_operations_view',
            table='ckk_item_operations_view',
        ),
    ]
