# Generated by Django 2.2.6 on 2019-10-22 22:07

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0079_auto_20191022_1242'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='precent_materials',
            options={'verbose_name': 'Комплектация'},
        ),
        migrations.RemoveField(
            model_name='demand',
            name='document',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='item',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='precent',
        ),
        migrations.AddField(
            model_name='demand',
            name='precent_dogovor',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent_dogovors'),
        ),
        migrations.AddField(
            model_name='demand',
            name='precent_item',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent_items'),
        ),
        migrations.AlterField(
            model_name='demand',
            name='status',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Status_demand'),
        ),
    ]
