# Generated by Django 3.0.3 on 2020-02-16 21:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0186_auto_20200216_2013'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ready_2_launch_detail',
            name='mat_view_name',
        ),
    ]
