# Generated by Django 2.2.1 on 2019-05-29 06:28

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0067_auto_20190529_0628'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='Документ'),
        ),
    ]
