# Generated by Django 3.0.3 on 2020-02-22 16:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0108_auto_20200222_1030'),
    ]

    operations = [
        migrations.CreateModel(
            name='Production_order',
            fields=[
            ],
            options={
                'verbose_name': 'Оприходования',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('planing.operations_view',),
        ),
    ]
