# Generated by Django 2.2.3 on 2019-07-31 17:05

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0136_auto_20190731_1632'),
    ]

    operations = [
        migrations.AddField(
            model_name='material_type',
            name='gost',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]
