# Generated by Django 2.1.7 on 2019-03-27 11:41

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0002_auto_20190327_1111'),
    ]

    operations = [
        migrations.AddField(
            model_name='document_attrs',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'),), blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='documents',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('beenItemed', 'Был внесен в состав изделий')), default=1),
        ),
    ]
