# Generated by Django 2.2.7 on 2019-11-18 13:50

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0105_auto_20191118_1130'),
    ]

    operations = [
        migrations.AddField(
            model_name='launch_item_line',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='launch_item_refs',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='launch_operation_resources',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='launch_operations_item',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='launch_operations_material',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
    ]
