# Generated by Django 3.0.3 on 2020-02-10 12:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0206_auto_20200209_1230'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='materials',
            name='Materials_unique_constraint_0',
        ),
        migrations.RemoveConstraint(
            model_name='materials',
            name='Materials_unique_constraint_1',
        ),
    ]
