# Generated by Django 2.2.1 on 2019-05-28 23:13

import bitfield.models
from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0046_precent_item_line'),
    ]

    operations = [
        migrations.CreateModel(
            name='Precent_item_line_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('section', isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Раздел')),
                ('subsection', isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Подраздел')),
                ('isFolder', models.BooleanField(default=False, verbose_name='Признак наличия потомков')),
                ('used', models.BooleanField(default=False, verbose_name='Признак используемости запуске')),
                ('props', bitfield.models.BitField((('relevant', 'Актуальность'),), default=1)),
            ],
            options={
                'verbose_name': 'Строка спецификации запуска',
                'db_table': 'ckk_item_line_mview',
                'ordering': ['section'],
                'managed': False,
            },
        ),
    ]
