# Generated by Django 3.0.3 on 2020-02-08 07:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0194_auto_20200208_0735'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='item',
            name='unique_with_optional',
        ),
    ]
