# Generated by Django 2.2.8 on 2019-12-04 20:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0163_locations_users'),
        ('production', '0143_operations_item_q_paralel'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('item', 'num', 'operation')},
        ),
    ]
