# Generated by Django 2.2.1 on 2019-05-24 15:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0038_precent_materials'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='precent_materials',
            name='ed_izm',
        ),
    ]
