# Generated by Django 2.2.1 on 2019-06-05 14:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0032_auto_20190530_1706'),
        ('ckk', '0070_auto_20190605_1415'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2')},
        ),
    ]
