# Generated by Django 2.2 on 2019-04-24 18:05

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0002_customer_parent'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='inn',
            field=isc_common.fields.code_field.CodeField(unique=True, verbose_name='ИНН'),
        ),
        migrations.AddField(
            model_name='customer',
            name='kpp',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='КПП'),
        ),
    ]
