# Generated by Django 2.2 on 2019-04-19 05:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0021_documents_view'),
        ('ckk', '0033_auto_20190419_0023'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2', 'props', 'document')},
        ),
    ]
