# Generated by Django 2.2.6 on 2019-10-23 11:19

import django.utils.timezone
from django.db import migrations, models

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0087_remove_demand_due_date'),
    ]

    operations = [
        migrations.CreateModel(
            name='Precent_items_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('qty', models.PositiveIntegerField()),
            ],
            options={
                'verbose_name': 'Комплектация распоряжения',
                'db_table': 'sales_precent_items_view',
                'managed': False,
            },
        ),
        migrations.AlterField(
            model_name='demand_materials',
            name='demand',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='sales.Demand'),
        ),
    ]
