# Generated by Django 3.0.3 on 2020-02-12 07:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0139_auto_20200211_0902'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='pathes',
            constraint=models.UniqueConstraint(condition=models.Q(parent=None), fields=('id',), name='Pathes_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='pathes',
            constraint=models.UniqueConstraint(fields=('id', 'parent'), name='Pathes_unique_constraint_1'),
        ),
    ]
