# Generated by Django 2.2.4 on 2019-08-22 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0051_remove_customer_full_name'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='customer',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='precent',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='precent_item_line',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='precent_items',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='precent_materials',
            name='id_old',
        ),
    ]
