# Generated by Django 2.2.1 on 2019-05-29 13:41

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0069_materials_material_1c'),
        ('production', '0038_resource_categories'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='category',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='production.Resource_categories'),
        ),
        migrations.AddField(
            model_name='resource',
            name='location',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
    ]
