# Generated by Django 2.2.1 on 2019-05-23 17:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0026_precent_items_qty'),
    ]

    operations = [
        migrations.AlterField(
            model_name='precent_items',
            name='qty',
            field=models.PositiveIntegerField(),
        ),
    ]
