# Generated by Django 2.2.6 on 2019-10-23 21:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0088_auto_20191023_1119'),
    ]

    operations = [
        migrations.RenameField(
            model_name='precent_dogovors',
            old_name='document',
            new_name='dogovor',
        ),
    ]
