# Generated by Django 3.0.2 on 2020-01-31 11:05

import django.db.models.expressions
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('ckk', '0189_auto_20200131_1059'),
    ]

    operations = [
        migrations.RunSQL('''delete from ckk_item_line where parent_id = child_id '''),
        migrations.AddConstraint(
            model_name='item_line',
            constraint=models.CheckConstraint(check=models.Q(_negated=True, child=django.db.models.expressions.F('parent')), name='Item_line_not_circulate_refs'),
        ),
    ]
