# Generated by Django 2.2.6 on 2019-10-22 22:24

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0085_demand_precent'),
    ]

    operations = [
        migrations.AlterField(
            model_name='demand',
            name='precent',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='sales.Precent'),
        ),
    ]
