# Generated by Django 2.2 on 2019-04-15 13:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0020_item_refs'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2')},
        ),
    ]
