# Generated by Django 2.2.8 on 2019-12-12 20:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0173_auto_20191212_2041'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='item_refs',
            name='syntetic_parent',
        ),
    ]
