# Generated by Django 3.0.4 on 2020-03-05 17:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0229_auto_20200305_1729'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs',
            name='qty_per_one',
            field=models.FloatField(default=None),
        ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(condition=models.Q(code=None), fields=('location', 'name'), name='Resource_unique_constraint_1'),
        ),
    ]
