# Generated by Django 2.2.7 on 2019-11-19 20:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='locations',
            options={'verbose_name': 'Место положения'},
        ),
    ]
