# Generated by Django 2.2.3 on 2019-07-07 07:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0125_material_params_order'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='materials',
            name='material_1C',
        ),
    ]
