# Generated by Django 2.2 on 2019-04-25 08:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0005_user_add_info'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Operation_plan_types',
        ),
    ]
