# Generated by Django 2.2 on 2019-04-25 08:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0003_auto_20190424_1805'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='customer',
            options={'verbose_name': 'Покупатель'},
        ),
    ]
