# Generated by Django 2.2.8 on 2019-12-15 01:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0109_auto_20191215_0106'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='lotsman_documents_hierarcy_refs',
            unique_together={('child', 'parent')},
        ),
    ]
