# Generated by Django 2.2.8 on 2019-12-13 16:25

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.files
import isc_common.fields.name_field
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0096_auto_20191213_1334'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='lotsman_documents',
            name='upload',
        ),
        migrations.AddField(
            model_name='lotsman_documents',
            name='file_access_time',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата время поcледнего доступа к документу'),
        ),
        migrations.AddField(
            model_name='lotsman_documents',
            name='file_change_time',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата время изменнения документа'),
        ),
        migrations.AddField(
            model_name='lotsman_documents',
            name='file_document',
            field=models.TextField(db_index=True, default=None, verbose_name='Полный путь к файлу'),
        ),
        migrations.AddField(
            model_name='lotsman_documents',
            name='file_modification_time',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата время поcледнего модификации документа'),
        ),
        migrations.AddField(
            model_name='lotsman_documents',
            name='file_size',
            field=models.PositiveIntegerField(default=None, verbose_name='Размер файла'),
        ),
        migrations.AlterField(
            model_name='lotsman_documents',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор'),
        ),
        migrations.CreateModel(
            name='Lotsman_documents_thumb10',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('format', isc_common.fields.name_field.NameField(blank=True, null=True, verbose_name='Формат файла')),
                ('mime_type', isc_common.fields.name_field.NameField(blank=True, default=None, null=True, verbose_name='MIME тип файла файла')),
                ('size', models.BigIntegerField(default=0, verbose_name='Размер фала')),
                ('real_name', models.TextField(blank=True, default=None, null=True, verbose_name='Первоначальное имя файла')),
                ('key', models.BinaryField(blank=True, max_length=200, null=True)),
                ('attfile', isc_common.fields.files.FileFieldEx(blank=True, default=None, max_length=255, null=True, upload_to='', verbose_name='Файл')),
                ('file_store', models.CharField(blank=True, max_length=255, null=True, verbose_name='Каталог хранения файла')),
                ('path', models.TextField()),
                ('document', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Lotsman_documents', verbose_name='КД')),
            ],
            options={
                'verbose_name': 'JPEG варианты документов',
            },
        ),
        migrations.CreateModel(
            name='Lotsman_documents_thumb',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('format', isc_common.fields.name_field.NameField(blank=True, null=True, verbose_name='Формат файла')),
                ('mime_type', isc_common.fields.name_field.NameField(blank=True, default=None, null=True, verbose_name='MIME тип файла файла')),
                ('size', models.BigIntegerField(default=0, verbose_name='Размер фала')),
                ('real_name', models.TextField(blank=True, default=None, null=True, verbose_name='Первоначальное имя файла')),
                ('key', models.BinaryField(blank=True, max_length=200, null=True)),
                ('attfile', isc_common.fields.files.FileFieldEx(blank=True, default=None, max_length=255, null=True, upload_to='', verbose_name='Файл')),
                ('file_store', models.CharField(blank=True, max_length=255, null=True, verbose_name='Каталог хранения файла')),
                ('path', models.TextField()),
                ('document', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Lotsman_documents', verbose_name='КД')),
            ],
            options={
                'verbose_name': 'JPEG варианты документов уменьшенная копия',
            },
        ),
    ]
