# Generated by Django 2.2.2 on 2019-06-14 19:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0105_auto_20190613_2223'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='item_production_specification',
            name='item',
        ),
        migrations.DeleteModel(
            name='Item_production_specificationView',
        ),
        migrations.DeleteModel(
            name='Item_production_specification',
        ),
    ]
