# Generated by Django 3.0.3 on 2020-03-01 05:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0120_operations_num'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='production_order',
            options={'verbose_name': 'Заказы на производство'},
        ),
        migrations.AlterModelTable(
            name='production_order',
            table='production_operations_view',
        ),
    ]
