# Generated by Django 2.2.2 on 2019-06-08 13:41

import bitfield.models
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0036_auto_20190607_1929'),
    ]

    operations = [
        migrations.CreateModel(
            name='Document_attrs_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('value_str', models.TextField(db_index=True, verbose_name='Значение атрибута')),
                ('props', bitfield.models.BitField((('relevant', 'Актуальность'), ('copied', 'Копированный')), db_index=True, default=1)),
            ],
            options={
                'verbose_name': 'Аттрибуты докуменнта',
                'db_table': 'kd_document_arrts_view',
                'managed': False,
            },
        ),
    ]
