# Generated by Django 3.0.3 on 2020-02-06 15:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0128_auto_20200206_1447'),
    ]

    operations = [
    ]
