# Generated by Django 2.2.6 on 2019-10-10 20:32

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0153_auto_20191010_1500'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_image_refs',
            name='thumb',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents_thumb'),
        ),
        migrations.AlterField(
            model_name='item_image_refs',
            name='thumb10',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents_thumb10'),
        ),
    ]
