# Generated by Django 3.0.2 on 2020-01-22 07:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounting', '0008_tmp_buffer_color'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tmp_buffer',
            name='color',
        ),
    ]
