# Generated by Django 2.2 on 2019-04-25 19:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0007_auto_20190425_1915'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='operation_plan_template_locations',
            options={'verbose_name': 'Место положение для шаблонов заданий в производство'},
        ),
        migrations.AlterField(
            model_name='operation_plan_template_locations',
            name='distribution_coefficient',
            field=models.IntegerField(default=1, verbose_name='Коэффициент распределения'),
        ),
    ]
