# Generated by Django 3.0.3 on 2020-02-21 15:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0102_auto_20200219_1446'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='operations_view',
            options={},
        ),
    ]
