# Generated by Django 2.2.8 on 2019-12-17 13:31

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0180_auto_20191217_1217'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_line',
            name='section',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]
