# Generated by Django 2.2.1 on 2019-05-28 20:49

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0042_auto_20190528_1710'),
    ]

    operations = [
        migrations.AlterField(
            model_name='precent',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='parent_p', to='sales.Precent'),
        ),
        migrations.AlterUniqueTogether(
            name='precent_items',
            unique_together=set(),
        ),
    ]
