# Generated by Django 2.2.4 on 2019-08-07 17:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0079_auto_20190806_1007'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pathes',
            name='props',
        ),
    ]
