# Generated by Django 3.0.3 on 2020-02-28 12:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0219_auto_20200227_2136'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='resource',
            name='Resource_unique_constraint_0',
        ),
        # migrations.RemoveConstraint(
        #     model_name='resource',
        #     name='Resource_unique_constraint_1',
        # ),
    ]
