# Generated by Django 2.2.6 on 2019-10-18 13:46

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0157_item_line_section_num'),
        ('sales', '0065_dogovors_view_precent_view'),
    ]

    operations = [
        migrations.AddField(
            model_name='precent_materials',
            name='edizm',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
    ]
