# Generated by Django 2.2.8 on 2019-12-08 09:00

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0161_auto_20191208_0859'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_operation_resources',
            name='launch_operationitem',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='production.Launch_operations_item'),
        ),
        migrations.AlterField(
            model_name='launch_operation_resources',
            name='location',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
        migrations.AlterField(
            model_name='launch_operation_resources',
            name='resource',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Resource'),
        ),
        migrations.AlterField(
            model_name='operation_resources',
            name='operationitem',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='production.Operations_item'),
        ),
    ]
