# Generated by Django 2.2.6 on 2019-10-18 11:59

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0157_item_line_section_num'),
        ('sales', '0063_auto_20191018_1149'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='precent_items',
            name='location',
        ),
        migrations.AddField(
            model_name='precent_materials',
            name='material_askon',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Material_askon'),
        ),
        migrations.AlterField(
            model_name='precent_materials',
            name='material',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Materials'),
        ),
    ]
