# Generated by Django 2.2.1 on 2019-05-30 11:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0040_auto_20190529_1341'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operations',
            name='code',
        ),
        migrations.RemoveField(
            model_name='operations',
            name='description',
        ),
        migrations.RemoveField(
            model_name='operations',
            name='name',
        ),
    ]
