# Generated by Django 2.2 on 2019-04-21 13:40

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0022_auto_20190421_1330'),
    ]

    operations = [
        migrations.CreateModel(
            name='Pathes_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('isFolder', models.BigIntegerField()),
                ('path', models.TextField(verbose_name='Путь')),
            ],
            options={
                'verbose_name': 'Пути нахождения документов',
                'db_table': 'kd_pathes_view',
                'managed': False,
            },
        ),
    ]
