# Generated by Django 3.0.3 on 2020-02-22 05:27

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0210_auto_20200212_0752'),
        ('planing', '0103_auto_20200221_1545'),
    ]

    operations = [
        # migrations.AddField(
        #     model_name='operations_view',
        #     name='material',
        #     field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Material_askon'),
        # ),
        # migrations.AddField(
        #     model_name='operations_view',
        #     name='production_operation_edizm',
        #     field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Operations_view_ed_izm', to='ckk.Ed_izm'),
        # ),
        # migrations.AddField(
        #     model_name='operations_view',
        #     name='production_operation_num',
        #     field=models.PositiveIntegerField(blank=True, null=True),
        # ),
        # migrations.AddField(
        #     model_name='operations_view',
        #     name='production_operation_qty',
        #     field=models.PositiveIntegerField(blank=True, null=True),
        # ),
    ]
