# Generated by Django 2.2.3 on 2019-07-09 01:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0129_auto_20190708_1544'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='materials',
            name='ed_izm',
        ),
    ]
