# Generated by Django 2.2.8 on 2019-12-06 11:34

import bitfield.models
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0022_auto_20191206_0923'),
    ]

    operations = [
        migrations.CreateModel(
            name='Operations',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
            ],
            options={
                'verbose_name': 'Опреации учавствующие в планировании',
            },
        ),
        migrations.AlterField(
            model_name='operation_types',
            name='props',
            field=bitfield.models.BitField((('isoper', 'Является операцией'), ('plus', 'Приходная операция'), ('minus', 'Расходная операция')), db_index=True, default=0),
        ),
    ]
