# Generated by Django 2.2.1 on 2019-06-05 15:33

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0071_auto_20190605_1416'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='Документ'),
        ),
    ]
