# Generated by Django 2.2.5 on 2019-09-18 14:37

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0002_auto_20190918_1428'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operationsplan',
            name='status',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='planing.OperationsPlanStatus'),
        ),
    ]
