# Generated by Django 3.0.2 on 2020-01-19 17:50

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0185_auto_20200117_1305'),
        ('planing', '0067_auto_20200119_1444'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_value',
            name='edizm',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
    ]
