# Generated by Django 2.2.1 on 2019-05-24 12:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0025_remove_materials_parent'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_material',
            name='material',
        ),
        migrations.RemoveField(
            model_name='operation_material',
            name='operation',
        ),
        migrations.DeleteModel(
            name='Materials',
        ),
        migrations.DeleteModel(
            name='Operation_material',
        ),
    ]
