# Generated by Django 2.1.7 on 2019-03-27 11:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='document_attrs',
            name='props',
        ),
        migrations.RemoveField(
            model_name='documents',
            name='props',
        ),
    ]
