# Generated by Django 2.2.4 on 2019-08-20 17:54

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0145_auto_20190820_1059'),
    ]

    operations = [
        migrations.CreateModel(
            name='Material_askon_mview',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('name', models.CharField(db_index=True, max_length=255, verbose_name='Информация в дерево материалов')),
                ('field1', models.CharField(blank=True, max_length=255, null=True, verbose_name='Материал.Наименование и документ')),
                ('field2', models.CharField(blank=True, max_length=255, null=True, verbose_name='Материал.Код')),
                ('field3', models.CharField(blank=True, max_length=255, null=True, verbose_name='Сортамент.Наименование и документ')),
                ('field4', models.CharField(blank=True, max_length=255, null=True, verbose_name='Экземпляр сортамента.Типоразмер')),
                ('field5', models.CharField(blank=True, max_length=255, null=True, verbose_name='Экземпляр сортамента.Обозначение')),
                ('field6', models.CharField(blank=True, max_length=255, null=True, verbose_name='Экземпляр сортамента.Статус')),
                ('field7', models.CharField(blank=True, max_length=255, null=True, verbose_name='Экземпляр сортамента.Код')),
                ('isFolder', models.BooleanField()),
            ],
            options={
                'verbose_name': 'Материалы из Асона',
                'db_table': 'ckk_material_askon_mview',
                'managed': False,
            },
        ),
    ]
