# Generated by Django 3.0.5 on 2020-04-17 14:20

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0223_item_qty_view'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_qty',
            name='child',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='Item_qty_child', to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='item_qty',
            name='parent',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='Item_qty_parent', to='ckk.Item'),
        ),
    ]
