# Generated by Django 2.2.2 on 2019-06-11 11:19

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.name_field
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0046_auto_20190610_0953'),
        ('ckk', '0090_auto_20190610_2018'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='item_view',
            table='ckk_item_view',
        ),
        migrations.CreateModel(
            name='Cdw_Pdf_Item_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('STMP_1', isc_common.fields.name_field.NameField(verbose_name='Наименование изделия')),
                ('STMP_2', isc_common.fields.name_field.NameField(verbose_name='Обозначение изделия')),
                ('isFolder', models.BooleanField(verbose_name='Обозначение изделия')),
                ('parent', models.BigIntegerField(blank=True, null=True)),
                ('relevant', isc_common.fields.name_field.NameField()),
                ('props1', models.PositiveIntegerField(default=0)),
                ('document', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='Документ')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
