# Generated by Django 2.2 on 2019-04-15 13:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0018_auto_20190414_0923'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Cdw',
        ),
        migrations.DeleteModel(
            name='Spw',
        ),
    ]
