# Generated by Django 2.2.8 on 2019-12-13 13:07

from django.db import migrations

from kaf_pas.ckk.models.attr_type import Attr_type


def rec_lotsman_attr_type(apps, schema_editor):
    KD, _ = Attr_type.objects.update_or_create(code='KD', defaults=dict(name='КД'))
    LOTSMAN, _ = Attr_type.objects.update_or_create(code='LOTSMAN', defaults=dict(parent=KD, name='Документы из Лоцмана'))
    return LOTSMAN


class Migration(migrations.Migration):
    dependencies = [
        ('kd', '0090_auto_20191213_1303'),
    ]

    operations = [
        migrations.RunPython(rec_lotsman_attr_type),
    ]
