# Generated by Django 2.2.1 on 2019-05-21 23:04

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0053_auto_20190521_1939'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='status',
            name='id_owner',
        ),
        migrations.AlterField(
            model_name='status',
            name='code_owner',
            field=isc_common.fields.code_field.CodeField(unique=True),
        ),
    ]
