# Generated by Django 2.2.6 on 2019-10-19 19:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0003_auto_20190918_1437'),
    ]

    operations = [
        migrations.AddField(
            model_name='operationsplan',
            name='quantity_minus',
            field=models.DecimalField(decimal_places=8, default=0, max_digits=20),
        ),
        migrations.AddField(
            model_name='operationsplan',
            name='quantity_plus',
            field=models.DecimalField(decimal_places=8, default=0, max_digits=20),
        ),
        migrations.AlterModelTable(
            name='operations_plan_view',
            table='planing_operationsplan_view',
        ),
        migrations.DeleteModel(
            name='Operations_plan_qtys',
        ),
    ]
