# Generated by Django 3.0.2 on 2020-01-18 15:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0061_auto_20200118_1439'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
    ]
