# Generated by Django 2.2.3 on 2019-07-28 19:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0075_remove_pathes_attr_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='pathes',
            name='virt_path',
            field=models.TextField(blank=True, null=True, verbose_name='Мнимый путь'),
        ),
    ]
