# Generated by Django 2.1.7 on 2019-03-27 11:41

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0003_auto_20190327_1111'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'),), default=1),
        ),
        migrations.AddField(
            model_name='item_line',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('relevant1', 'Актуальность1')), default=1),
        ),
    ]
