# Generated by Django 2.2.1 on 2019-05-25 09:53

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0060_auto_20190524_1536'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_image_refs',
            name='item',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='ckk.Item'),
        ),
    ]
