# Generated by Django 2.1.7 on 2019-03-28 07:05

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0003_auto_20190327_1141'),
        ('ckk', '0005_auto_20190327_2032'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='Документ'),
        ),
    ]
