# Generated by Django 2.2.2 on 2019-07-01 17:12

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0116_auto_20190701_1705'),
    ]

    operations = [
        migrations.AddField(
            model_name='materials',
            name='type',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Material_type'),
        ),
    ]
