# Generated by Django 2.2.8 on 2019-12-12 18:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0169_item_refs_syntetic_child'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item_refs',
            unique_together={('child', 'parent', 'syntetic_child')},
        ),
    ]
