# Generated by Django 3.0.3 on 2020-02-17 13:55

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0192_auto_20200217_1221'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_operations_item',
            name='operationitem',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Operations_item'),
        ),
    ]
