# Generated by Django 3.0.3 on 2020-03-02 08:08

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0123_auto_20200301_1424'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_value',
            name='props',
            field=bitfield.models.BitField((('perone', 'Из расчета на еденицу продукции'),), db_index=True, default=0),
        ),
    ]
