# Generated by Django 2.2 on 2019-04-14 07:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0010_auto_20190413_0700'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attr_type',
            name='deleted',
            field=models.BooleanField(blank=True, db_index=True, null=True, verbose_name='Признак удаления'),
        ),
        migrations.AlterField(
            model_name='item',
            name='deleted',
            field=models.BooleanField(blank=True, db_index=True, null=True, verbose_name='Признак удаления'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='deleted',
            field=models.BooleanField(blank=True, db_index=True, null=True, verbose_name='Признак удаления'),
        ),
        migrations.AlterField(
            model_name='item_line_refs',
            name='deleted',
            field=models.BooleanField(blank=True, db_index=True, null=True, verbose_name='Признак удаления'),
        ),
    ]
