# Generated by Django 2.2.2 on 2019-06-10 10:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0087_auto_20190610_0953'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='materials',
            name='code',
        ),
        migrations.RemoveField(
            model_name='materials',
            name='description',
        ),
        migrations.RemoveField(
            model_name='materials',
            name='name',
        ),
    ]
