# Generated by Django 3.0.3 on 2020-02-28 12:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0220_auto_20200228_1211'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(condition=models.Q(('code', None), ('name', None)), fields=('location',), name='Resource_unique_constraint_0'),
        ),
        # migrations.AddConstraint(
        #     model_name='resource',
        #     constraint=models.UniqueConstraint(condition=models.Q(code=None), fields=('location', 'name'), name='Resource_unique_constraint_1'),
        # ),
    ]
