# Generated by Django 3.0.3 on 2020-02-29 11:57

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0212_auto_20200225_1013'),
        ('production', '0221_auto_20200228_1240'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs',
            name='item_refs',
            field=isc_common.fields.related.ForeignKeySetNull(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ckk.Item_refs'),
        ),
    ]
