# Generated by Django 2.2.8 on 2019-12-17 12:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0117_auto_20191217_0709'),
        ('ckk', '0179_item_lotsman_document'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2', 'version')},
        ),
    ]
