# Generated by Django 3.0.3 on 2020-02-26 14:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0211_auto_20200226_1224'),
    ]

    operations = [
        # migrations.RemoveConstraint(
        #     model_name='resource',
        #     name='Resource_unique_constraint_0',
        # ),
        # migrations.RemoveConstraint(
        #     model_name='resource',
        #     name='Resource_unique_constraint_1',
        # ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(condition=models.Q(('code', None), ('name', None)), fields=('location',), name='Resource_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(condition=models.Q(code=None), fields=('location', 'name'), name='Resource_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(condition=models.Q(name=None), fields=('code', 'location'), name='Resource_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='resource',
            constraint=models.UniqueConstraint(fields=('code', 'location', 'name'), name='Resource_unique_constraint_3'),
        ),
    ]
