# Generated by Django 2.2 on 2019-04-13 07:00

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0009_auto_20190412_2045'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_line_refs',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='parent', to='ckk.Item_line'),
        ),
        migrations.AlterUniqueTogether(
            name='item_line_refs',
            unique_together={('child', 'parent')},
        ),
    ]
