# Generated by Django 2.2.8 on 2019-12-12 21:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0175_item_refs_syntetic_parent'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item_refs',
            unique_together={('child', 'parent')},
        ),
        migrations.RemoveField(
            model_name='item_refs',
            name='syntetic_child',
        ),
        migrations.RemoveField(
            model_name='item_refs',
            name='syntetic_parent',
        ),
    ]
