# Generated by Django 2.1.7 on 2019-03-27 07:03

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('kd', '0001_initial'),
        ('ckk', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_COUNT',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_COUNT', to='kd.Document_attrs', verbose_name='Количество'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_FACTORY',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_FACTORY', to='kd.Document_attrs', verbose_name='Предприятие - изготовитель'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_FORMAT',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_FORMAT', to='kd.Document_attrs', verbose_name='Формат'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_KOD',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_KOD', to='kd.Document_attrs', verbose_name='Код'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_MARK',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_MARK', to='kd.Document_attrs', verbose_name='Обозначение'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_MASSA',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_MASSA', to='kd.Document_attrs', verbose_name='Масса'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_MATERIAL',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_MATERIAL', to='kd.Document_attrs', verbose_name='Материал'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_NAME',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_NAME', to='kd.Document_attrs', verbose_name='Наименование'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_NOTE',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_NOTE', to='kd.Document_attrs', verbose_name='Примечание'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_POS',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_POS', to='kd.Document_attrs', verbose_name='Позиция'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_USER',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_USER', to='kd.Document_attrs', verbose_name='Пользовательская'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='SPC_CLM_ZONE',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_ZONE', to='kd.Document_attrs', verbose_name='Зона'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='Документ'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='item_child',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='item_child', to='ckk.Item'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='item_parent',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='item_parent', to='ckk.Item'),
        ),
        migrations.AddField(
            model_name='item',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='Документ'),
        ),
        migrations.AddField(
            model_name='attr_type',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Attr_type'),
        ),
    ]
