# Generated by Django 2.2.7 on 2019-11-21 09:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0014_auto_20191121_0623'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs_timing',
            name='time_duration_operations',
            field=models.DecimalField(blank=True, decimal_places=4, default=0.0, max_digits=19, null=True),
        ),
    ]
