# Generated by Django 2.2.2 on 2019-06-08 19:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0037_document_attrs_view'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documents',
            name='file_access_time',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата время поcледнего доступа к документу'),
        ),
        migrations.AlterField(
            model_name='documents',
            name='file_change_time',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата время изменнения документа'),
        ),
        migrations.AlterField(
            model_name='documents',
            name='file_document',
            field=models.TextField(db_index=True, verbose_name='Полный путь к файлу'),
        ),
        migrations.AlterField(
            model_name='documents',
            name='file_modification_time',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата время поcледнего модификации документа'),
        ),
    ]
