# Generated by Django 3.0.3 on 2020-02-08 07:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0193_auto_20200208_0714'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(STMP_1=None), fields=('STMP_1', 'STMP_2', 'version', 'lotsman_type_id'), name='unique_with_optional'),
        ),
    ]
