# Generated by Django 3.0.3 on 2020-02-17 13:23

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0093_auto_20200217_0915'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_item',
            name='item_full_name',
            field=models.TextField(default=None),
        ),
        migrations.AddField(
            model_name='operation_item',
            name='item_full_name_obj',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
    ]
