# Generated by Django 3.0.3 on 2020-02-28 12:11

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0112_auto_20200224_1448'),
    ]

    operations = [
        migrations.AddField(
            model_name='status_operation_types',
            name='color',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]
