# Generated by Django 2.2.6 on 2019-10-28 21:08

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0100_auto_20191028_2105'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='props',
            field=bitfield.models.BitField((('real', 'Реальный клиент'),), db_index=True, default=1),
        ),
        migrations.AddField(
            model_name='dogovor_types',
            name='props',
            field=bitfield.models.BitField((('real', 'Реальный тим'),), db_index=True, default=1),
        ),
        migrations.AddField(
            model_name='statusdogovor',
            name='props',
            field=bitfield.models.BitField((('real', 'Реальный статус'),), db_index=True, default=1),
        ),
    ]
