# Generated by Django 3.0.3 on 2020-02-18 15:05

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ckk', '0210_auto_20200212_0752'),
        ('production', '0195_remove_launches_facets'),
        ('isc_common', '0050_deleted_progresses'),
        ('planing', '0097_auto_20200218_1218'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_operation',
            name='num',
            field=models.PositiveIntegerField(default=None),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='color',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='isc_common.Standard_colors'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='creator',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='date',
            field=models.DateTimeField(default=None),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='edizm',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='isFolder',
            field=models.BooleanField(default=None),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='item',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Item'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='item_full_name',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='launch',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Launches'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='location',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='operation_level',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='planing.Levels'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='opertype',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='planing.Operation_types'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='production_operation',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Operations'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='resource',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Resource'),
        ),
        migrations.AddField(
            model_name='operations_view',
            name='status',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='planing.Status_operation_types'),
        ),
        migrations.AlterModelTable(
            name='operations_view',
            table=None,
        ),
    ]
