# Generated by Django 2.2.8 on 2019-12-07 18:02

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0038_auto_20191207_1801'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_launch_operation_material',
            name='edizm',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AlterField(
            model_name='operation_launch_operations_item',
            name='ed_izm',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AlterField(
            model_name='operation_launch_operations_item',
            name='num',
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterField(
            model_name='operation_launch_operations_item',
            name='operation',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_launch_operations_item',
            name='qty',
            field=models.PositiveIntegerField(),
        ),
    ]
