# Generated by Django 3.0.3 on 2020-02-28 12:40

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0113_status_operation_types_color'),
    ]

    operations = [
        migrations.AlterField(
            model_name='status_operation_types',
            name='props',
            field=bitfield.models.BitField((('disabled', 'Неактивная запись в гриде'), ('blink', 'Мигающее поле в гриде')), db_index=True, default=0),
        ),
    ]
