# Generated by Django 2.2.8 on 2019-12-07 18:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0041_auto_20191207_1811'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='resource_loading',
            name='launch_operations_item',
        ),
        migrations.RemoveField(
            model_name='resource_loading',
            name='resource',
        ),
        migrations.DeleteModel(
            name='Location_loading',
        ),
        migrations.DeleteModel(
            name='Resource_loading',
        ),
    ]
