# Generated by Django 2.2.8 on 2019-12-12 17:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0165_item_refs_hierarcy'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='item_refs_hierarcy',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='item_refs_hierarcy',
            name='deliting',
        ),
        migrations.RemoveField(
            model_name='item_refs_hierarcy',
            name='editing',
        ),
        migrations.RemoveField(
            model_name='item_refs_hierarcy',
            name='lastmodified',
        ),
        migrations.RemoveField(
            model_name='item_refs_hierarcy',
            name='parent',
        ),
        migrations.AlterField(
            model_name='item_refs_hierarcy',
            name='id',
            field=models.BigIntegerField(primary_key=True, serialize=False),
        ),
    ]
