# Generated by Django 2.2.1 on 2019-05-28 22:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0044_auto_20190528_2155'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Precent_locations',
        ),
    ]
