# Generated by Django 2.2.2 on 2019-06-07 18:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0080_auto_20190607_1852'),
        ('kd', '0034_document_attr_cross_document_attributes'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='document_attributes',
            unique_together={('attr_type', 'value_str', 'props')},
        ),
    ]
