# Generated by Django 3.0.3 on 2020-02-19 03:16

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0210_auto_20200212_0752'),
        ('planing', '0098_auto_20200218_1505'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_operation',
            name='ed_izm',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AddField(
            model_name='operation_operation',
            name='qty',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='operation_operation',
            name='num',
            field=models.PositiveIntegerField(),
        ),
    ]
