# Generated by Django 2.2.7 on 2019-11-17 04:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0087_launch_item_line_launch_item_refs_launch_items_launches'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Item_refs',
        ),
    ]
