# Generated by Django 2.2.7 on 2019-11-20 14:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0159_auto_20191119_2034'),
        ('production', '0126_auto_20191120_1441'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='launch_item_line',
            unique_together={('parent', 'child', 'launch', 'added_parent')},
        ),
    ]
