# Generated by Django 2.2 on 2019-04-17 18:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0020_cdw_attrs_spw_attrs'),
        ('ckk', '0027_auto_20190417_1821'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item_image_refs',
            unique_together={('item', 'thumb', 'thumb10')},
        ),
    ]
