# Generated by Django 2.2.6 on 2019-10-22 12:31

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0076_precent_items_itemtype'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='demand',
            name='customer',
        ),
        migrations.AddField(
            model_name='demand',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Dogovors'),
        ),
        migrations.AddField(
            model_name='demand',
            name='precent',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent'),
        ),
    ]
