# Generated by Django 2.2.1 on 2019-05-28 15:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0030_auto_20190525_1331'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='documents_view',
            table='kd_documents_mview',
        ),
        migrations.AlterModelTable(
            name='pathes_view',
            table='kd_pathes_mview',
        ),
    ]
