# Generated by Django 3.0.3 on 2020-02-08 14:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0131_auto_20200207_0822'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='document_attributes',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='document_attributes',
            constraint=models.UniqueConstraint(condition=models.Q(value_int=None), fields=('attr_type', 'value_str'), name='Document_attributes_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='document_attributes',
            constraint=models.UniqueConstraint(fields=('attr_type', 'value_int', 'value_str'), name='Document_attributes_unique_constraint_1'),
        ),
    ]
