# Generated by Django 2.2.8 on 2019-12-15 01:13

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0110_auto_20191215_0108'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lotsman_documents_hierarcy_refs',
            name='parent',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='Lotsman_documents_hierarcy_parent', to='kd.Lotsman_documents_hierarcy'),
        ),
    ]
