# Generated by Django 2.2.4 on 2019-08-04 12:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0077_documents_mview'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='documents_thumb',
            name='props',
        ),
        migrations.RemoveField(
            model_name='documents_thumb10',
            name='props',
        ),
    ]
