# Generated by Django 2.2.1 on 2019-05-21 18:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0051_remove_status_id_owner'),
        ('ckk', '0043_auto_20190521_1853'),
    ]

    operations = [
    ]
