# Generated by Django 3.0.3 on 2020-02-17 04:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0087_auto_20200209_1244'),
    ]

    operations = [
        migrations.CreateModel(
            name='Routing',
            fields=[
            ],
            options={
                'verbose_name': 'Маршрутизация',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('planing.operations_view',),
        ),
    ]
