# Generated by Django 2.2.1 on 2019-05-28 15:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0061_auto_20190525_0953'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='item_line_view',
            table='ckk_item_line_mview',
        ),
        migrations.AlterModelTable(
            name='item_view',
            table='ckk_item_mveiw',
        ),
    ]
