# Generated by Django 2.2.1 on 2019-05-23 11:25

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0054_auto_20190521_2304'),
    ]

    operations = [
        migrations.AlterField(
            model_name='status',
            name='code_owner',
            field=isc_common.fields.code_field.CodeField(),
        ),
    ]
