# Generated by Django 3.0.2 on 2020-01-20 21:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounting', '0005_auto_20200119_1744'),
    ]

    operations = [
        migrations.AddField(
            model_name='tmp_buffer',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
    ]
