# Generated by Django 2.2.8 on 2019-12-06 13:29

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0027_auto_20191206_1329'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_types_users',
            name='operation_type',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='planing.Operation_types'),
        ),
    ]
