# Generated by Django 2.2.2 on 2019-06-07 17:21

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0078_auto_20190606_1839'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='item_line',
            name='isFolder',
        ),
        migrations.AlterField(
            model_name='item',
            name='STMP_1',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='STMP_1', to='kd.Document_attributes', verbose_name='Наименование изделия'),
        ),
        migrations.AlterField(
            model_name='item',
            name='STMP_2',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='STMP_2', to='kd.Document_attributes', verbose_name='Обозначение изделия'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_COUNT',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_COUNT', to='kd.Document_attributes', verbose_name='Количество'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_FACTORY',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_FACTORY', to='kd.Document_attributes', verbose_name='Предприятие - изготовитель'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_FORMAT',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_FORMAT', to='kd.Document_attributes', verbose_name='Формат'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_KOD',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_KOD', to='kd.Document_attributes', verbose_name='Код'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_MARK',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_MARK', to='kd.Document_attributes', verbose_name='Обозначение'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_MASSA',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_MASSA', to='kd.Document_attributes', verbose_name='Масса'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_MATERIAL',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_MATERIAL', to='kd.Document_attributes', verbose_name='Материал'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_NAME',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_NAME', to='kd.Document_attributes', verbose_name='Наименование'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_NOTE',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_NOTE', to='kd.Document_attributes', verbose_name='Примечание'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_POS',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_POS', to='kd.Document_attributes', verbose_name='Позиция'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_USER',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_USER', to='kd.Document_attributes', verbose_name='Пользовательская'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='SPC_CLM_ZONE',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='SPC_CLM_ZONE', to='kd.Document_attributes', verbose_name='Зона'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='section',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='section', to='kd.Document_attributes', verbose_name='Секция'),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='subsection',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='subsection', to='kd.Document_attributes', verbose_name='Подсекция'),
        ),
    ]
