# Generated by Django 2.2.7 on 2019-11-16 13:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0014_auto_20191013_1142'),
    ]

    operations = [
        migrations.AddField(
            model_name='user_add_info',
            name='ip_address',
            field=models.CharField(blank=True, max_length=20, null=True),
        ),
        migrations.AddField(
            model_name='user_add_info',
            name='user_agent',
            field=models.TextField(blank=True, null=True),
        ),
    ]
