# Generated by Django 2.2.2 on 2019-06-11 11:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0092_auto_20190611_1151'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cdw_pdf_item_view',
            options={'managed': False, 'verbose_name': 'Чертеж'},
        ),
    ]
