# Generated by Django 2.2.4 on 2019-08-22 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0146_material_askon_mview'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='attr_type',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='ed_izm',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='files_askon',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='item',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='item_image_refs',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='item_line',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='item_location',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='item_refs',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='locations',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='material_added_values',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='material_askon',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='material_params',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='material_type',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='materials',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='status',
            name='id_old',
        ),
    ]
