# Generated by Django 2.2.6 on 2019-10-20 18:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0157_item_line_section_num'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Status',
        ),
    ]
