# Generated by Django 2.2.8 on 2019-12-02 12:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0134_auto_20191121_2223'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='launch_item_refs',
            options={'verbose_name': 'Древо производственной спецификации'},
        ),
    ]
