# Generated by Django 2.2.6 on 2019-10-29 14:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0106_auto_20191029_1413'),
    ]

    operations = [
        migrations.RenameField(
            model_name='dogovors',
            old_name='code',
            new_name='name',
        ),
    ]
