# Generated by Django 2.2.1 on 2019-05-18 21:36

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0026_auto_20190518_1703'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attrs',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'),), db_index=True, default=1),
        ),
    ]
