# Generated by Django 3.0.3 on 2020-02-22 05:48

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0210_auto_20200212_0752'),
        ('planing', '0104_auto_20200222_0527'),
    ]

    operations = [
        # migrations.AddField(
        #     model_name='operations_view',
        #     name='std_material',
        #     field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Materials'),
        # ),
    ]
