# Generated by Django 2.2.1 on 2019-05-22 07:46

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0016_auto_20190521_2028'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='precent',
            options={'verbose_name': 'Документы'},
        ),
        migrations.AddField(
            model_name='precent',
            name='type',
            field=isc_common.fields.code_field.CodeField(),
        ),
    ]
