# Generated by Django 2.2.8 on 2019-12-13 13:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0094_auto_20191213_1323'),
    ]

    operations = [
    ]
