# Generated by Django 2.2.8 on 2019-12-15 01:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0108_auto_20191215_0105'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lotsman_documents_hierarcy',
            name='id',
            field=models.BigIntegerField(primary_key=True, serialize=False, verbose_name='Идентификатор'),
        ),
    ]
