# Generated by Django 2.2.8 on 2019-12-04 20:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0146_auto_20191204_2015'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launch_operations_item',
            name='q_paralel',
        ),
        migrations.RemoveField(
            model_name='operations_item',
            name='q_paralel',
        ),
        migrations.AddField(
            model_name='operation_resources',
            name='q_paralel',
            field=models.PositiveIntegerField(default=1),
        ),
    ]
