# Generated by Django 3.0.2 on 2020-01-22 19:23

from django.db import migrations
import kaf_pas.input.models.users_ex


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0034_standard_colors_color'),
        ('input', '0016_user_agg_view'),
    ]

    operations = [
        migrations.CreateModel(
            name='Users_ex',
            fields=[
            ],
            options={
                'verbose_name': 'Пользователи с должностями',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('isc_common.user',),
            managers=[
                ('objects', kaf_pas.input.models.users_ex.Users_exManager()),
            ],
        ),
    ]
