# Generated by Django 2.2.1 on 2019-05-21 15:17

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0013_auto_20190517_1641'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='precent',
            name='name',
        ),
        migrations.AddField(
            model_name='precent',
            name='customer',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Customer'),
        ),
        migrations.AddField(
            model_name='precent',
            name='date',
            field=models.DateTimeField(default=None, verbose_name='Дата'),
        ),
        migrations.AddField(
            model_name='precent',
            name='date_sign',
            field=models.DateTimeField(default=None, verbose_name='Дата подписания'),
        ),
    ]
