# Generated by Django 3.0.2 on 2020-01-22 06:06

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('accounting', '0007_tmp_buffer_value_off'),
    ]

    operations = [
        migrations.AddField(
            model_name='tmp_buffer',
            name='color',
            field=isc_common.fields.code_field.ColorField(blank=True, null=True),
        ),
    ]
