# Generated by Django 2.2.2 on 2019-06-10 00:56

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0042_auto_20190610_0047'),
    ]

    operations = [
        migrations.AddField(
            model_name='document_attr_cross',
            name='section',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Раздел'),
        ),
        migrations.AddField(
            model_name='document_attr_cross',
            name='subsection',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Подраздел'),
        ),
    ]
