# Generated by Django 2.2.3 on 2019-07-03 22:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0123_material_added_values'),
    ]

    operations = [
        migrations.AlterField(
            model_name='material_type',
            name='code',
            field=models.CharField(max_length=255, unique=True),
        ),
    ]
