# Generated by Django 2.2.2 on 2019-06-24 13:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0048_auto_20190613_1526'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='document_attributes_view',
            table='kd_document_attrs_view',
        ),
    ]
