# Generated by Django 2.2.7 on 2019-11-17 16:54

import django.utils.timezone
from django.db import migrations, models

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0094_status_launch_props'),
    ]

    operations = [
        migrations.CreateModel(
            name='Launch_item_refs',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('child', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='launch_child', to='production.Launch_items')),
                ('item_refs', isc_common.fields.related.ForeignKeySetNull(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ckk.Item_refs')),
                ('parent', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='launch_parent', to='production.Launch_items')),
            ],
            options={
                'verbose_name': 'Кросс таблица',
            },
        ),
    ]
