# Generated by Django 2.1.7 on 2019-03-27 20:32

import bitfield.models
from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0004_auto_20190327_1141'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='item_line',
            options={'ordering': ['section'], 'verbose_name': 'Строка состава изделия'},
        ),
        migrations.RemoveField(
            model_name='item',
            name='document',
        ),
        migrations.RemoveField(
            model_name='item_line',
            name='item_child',
        ),
        migrations.RemoveField(
            model_name='item_line',
            name='item_parent',
        ),
        migrations.AddField(
            model_name='item_line',
            name='isFolder',
            field=models.BooleanField(default=False, verbose_name='Подраздел'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='item',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Item', verbose_name='Товарная позиция'),
        ),
        migrations.AddField(
            model_name='item_line',
            name='parent',
            field=models.ManyToManyField(blank=True, null=True, to='ckk.Item_line'),
        ),
        migrations.AlterField(
            model_name='item',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('relevant1', 'Актуальность1')), default=1),
        ),
    ]
