# Generated by Django 3.0.4 on 2020-03-29 03:29

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0145_auto_20200326_1924'),
    ]

    operations = [
        migrations.AlterField(
            model_name='uploades',
            name='path',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Pathes'),
        ),
        migrations.AlterField(
            model_name='uploades_documents',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Documents'),
        ),
        migrations.AlterField(
            model_name='uploades_documents',
            name='upload',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Uploades'),
        ),
    ]
