# Generated by Django 3.0.3 on 2020-02-27 08:59

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0213_auto_20200227_0819'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations_template',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Operations_template'),
        ),
        # migrations.AddConstraint(
        #     model_name='resource',
        #     constraint=models.UniqueConstraint(condition=models.Q(('code', None), ('name', None)), fields=('location',), name='Resource_unique_constraint_0'),
        # ),
        # migrations.AddConstraint(
        #     model_name='resource',
        #     constraint=models.UniqueConstraint(condition=models.Q(code=None), fields=('location', 'name'), name='Resource_unique_constraint_1'),
        # ),
    ]
