# Generated by Django 2.2.3 on 2019-07-03 11:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('refs', '0004_type_param_values'),
        ('ckk', '0121_auto_20190703_0506'),
    ]

    operations = [
        migrations.RenameField(
            model_name='material_params',
            old_name='meterial_type',
            new_name='materials_type',
        ),
        migrations.RenameField(
            model_name='materials',
            old_name='type',
            new_name='materials_type',
        ),
        migrations.AlterUniqueTogether(
            name='material_params',
            unique_together={('materials_type', 'param_type')},
        ),
    ]
