# Generated by Django 2.2.8 on 2019-12-06 15:54

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0029_status_operation_types'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations',
            name='status',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='planing.Status_operation_types'),
        ),
    ]
