# Generated by Django 3.0.3 on 2020-02-09 11:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0173_auto_20200208_1435'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='launch_operations_item',
            name='Launch_operations_item_unique_constraint_0',
        ),
        migrations.RemoveConstraint(
            model_name='launch_operations_item',
            name='Launch_operations_item_unique_constraint_1',
        ),
        migrations.AddConstraint(
            model_name='launch_operations_item',
            constraint=models.UniqueConstraint(condition=models.Q(num=None), fields=('item', 'launch', 'operation'), name='Launch_operations_item_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='launch_operations_item',
            constraint=models.UniqueConstraint(fields=('item', 'launch', 'num', 'operation'), name='Launch_operations_item_unique_constraint_1'),
        ),
    ]
