# Generated by Django 2.2.4 on 2019-08-30 17:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0150_status_code_owner'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='status',
            unique_together=set(),
        ),
    ]
