# Generated by Django 2.2.1 on 2019-05-21 18:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0008_auto_20190521_1853'),
        ('sales', '0014_auto_20190521_1517'),
    ]

    operations = [
    ]
