# Generated by Django 2.2.5 on 2019-09-16 17:59

from django.db import migrations
import isc_common.fields.description_field


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0011_user_add_info_color'),
    ]

    operations = [
        migrations.AddField(
            model_name='user_add_info',
            name='phones',
            field=isc_common.fields.description_field.DescriptionField(),
        ),
    ]
