# Generated by Django 2.2.2 on 2019-07-01 17:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0114_material_type_parent'),
    ]

    operations = [
        migrations.AlterField(
            model_name='material_type',
            name='code',
            field=models.CharField(default=None, max_length=255),
        ),
        migrations.AlterField(
            model_name='material_type',
            name='name',
            field=models.CharField(default=None, max_length=255),
        ),
    ]
