# Generated by Django 2.2.3 on 2019-07-20 13:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0071_auto_20190720_1313'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='document_attr_cross',
            unique_together={('document', 'position_in_document')},
        ),
    ]
