# Generated by Django 2.2.1 on 2019-05-29 11:12

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0031_auto_20190529_1111'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operations',
            name='category',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operation_categories'),
        ),
    ]
