# Generated by Django 2.2.6 on 2019-10-18 11:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0061_auto_20190918_1459'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dogovors',
            name='date',
            field=models.DateTimeField(db_index=True, default=None, verbose_name='Дата'),
        ),
        migrations.AlterField(
            model_name='precent',
            name='date',
            field=models.DateTimeField(db_index=True, default=None, verbose_name='Дата'),
        ),
    ]
