# Generated by Django 2.2.8 on 2019-12-25 20:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0004_contants_parent'),
    ]

    operations = [
        migrations.AddField(
            model_name='contants',
            name='value',
            field=models.TextField(blank=True, null=True),
        ),
    ]
