# Generated by Django 2.2 on 2019-04-13 12:15

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0006_auto_20190413_1116'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documents',
            name='props',
            field=bitfield.models.BitField(('relevant', 'Актуальность'), default=1),
        ),
    ]
