# Generated by Django 2.2.4 on 2019-08-08 13:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0080_remove_pathes_props'),
        ('ckk', '0139_item_version'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2', 'props', 'version')},
        ),
    ]
