# Generated by Django 3.0.2 on 2020-01-19 16:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounting', '0002_buffers'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='buffers',
            table='accounting_buffers_view',
        ),
    ]
