# Generated by Django 3.0.2 on 2020-01-22 17:45

from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('input', '0015_auto_20191116_1321'),
    ]

    operations = [
        migrations.CreateModel(
            name='User_agg_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('username', isc_common.fields.code_field.CodeField(blank=True, null=True)),
                ('first_name', isc_common.fields.name_field.NameField(blank=True, null=True)),
                ('last_name', isc_common.fields.name_field.NameField(blank=True, null=True)),
                ('email', models.EmailField(blank=True, max_length=254, null=True)),
                ('middle_name', isc_common.fields.name_field.NameField(blank=True, null=True)),
                ('location_position', isc_common.fields.name_field.NameField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'Пользователи',
                'db_table': 'user_agg_view',
                'managed': False,
            },
        ),
    ]
