# Generated by Django 2.2.5 on 2019-09-17 18:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0052_auto_20190822_2250'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='precent_item_line',
            name='item_line',
        ),
        migrations.RemoveField(
            model_name='precent_item_line',
            name='location',
        ),
        migrations.RemoveField(
            model_name='precent_item_line',
            name='precent',
        ),
        migrations.DeleteModel(
            name='Precent_item_line_view',
        ),
        migrations.DeleteModel(
            name='Precent_item_line',
        ),
    ]
