# Generated by Django 3.0.4 on 2020-03-18 12:00

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0141_auto_20200222_1755'),
    ]

    operations = [
        migrations.AddField(
            model_name='pathes',
            name='props',
            field=bitfield.models.BitField((('enable_upload', 'Директория для закачки'),), db_index=True, default=0),
        ),
    ]
