# Generated by Django 2.2.8 on 2019-12-07 10:31

from django.db import migrations

from kaf_pas.production.models.operations_item import Operations_itemManager


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0156_auto_20191207_0910'),
    ]

    operations = [
        migrations.RunPython(Operations_itemManager.refresh_num),
    ]
