# Generated by Django 2.2.8 on 2019-12-07 23:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0043_operations_level'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_launch_operation_resources',
            name='launch_operation_resources',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operation_resources',
            name='operation',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operations_item',
            name='launch_operations_item',
        ),
        migrations.RemoveField(
            model_name='operation_launch_operations_item',
            name='operation',
        ),
        migrations.DeleteModel(
            name='Operation_launch_operation_material',
        ),
        migrations.DeleteModel(
            name='Operation_launch_operation_resources',
        ),
        migrations.DeleteModel(
            name='Operation_launch_operations_item',
        ),
    ]
