# Generated by Django 2.2.6 on 2019-10-19 19:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0004_auto_20191019_1955'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operationsplan',
            name='quantity_minus',
            field=models.DecimalField(decimal_places=8, max_digits=20),
        ),
        migrations.AlterField(
            model_name='operationsplan',
            name='quantity_plus',
            field=models.DecimalField(decimal_places=8, max_digits=20),
        ),
    ]
