# Generated by Django 2.2.7 on 2019-11-18 11:27

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0103_auto_20191118_1027'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='launch_item_line',
            unique_together={('parent', 'child', 'launch')},
        ),
        migrations.AlterUniqueTogether(
            name='launch_item_refs',
            unique_together={('parent', 'child', 'launch')},
        ),
    ]
