# Generated by Django 2.2.8 on 2019-12-16 10:16

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0115_lotsman_documents_hierarcy_props'),
        ('ckk', '0178_auto_20191216_0758'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='lotsman_document',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Lotsman_documents_hierarcy', verbose_name='Документ из Лоцмана'),
        ),
    ]
