# Generated by Django 2.2 on 2019-04-20 17:57

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0035_auto_20190420_1208'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('from_cdw', 'Получено из чертежа'), ('for_line', 'Строка спецификации')), default=1),
        ),
    ]
