# Generated by Django 2.2 on 2019-04-18 10:20

from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0028_auto_20190417_1833'),
    ]

    operations = [
        migrations.CreateModel(
            name='Item_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('STMP_1', isc_common.fields.name_field.NameField(verbose_name='Наименование изделия')),
                ('STMP_2', isc_common.fields.name_field.NameField(verbose_name='Обозначение документа')),
                ('relevant', isc_common.fields.code_field.CodeField(verbose_name='Актуальность документа')),
                ('parent_id', models.BigIntegerField()),
                ('props', models.BigIntegerField()),
                ('isFolder', models.BooleanField()),
            ],
            options={
                'verbose_name': 'Товарная позиция',
                'db_table': 'ckk_item_veiw',
                'managed': False,
            },
        ),
    ]
