# Generated by Django 2.2.6 on 2019-10-07 16:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0064_auto_20190918_0146'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations_item',
            name='num',
            field=models.PositiveIntegerField(blank=True, default=None, null=True),
        ),
    ]
