# Generated by Django 2.2.6 on 2019-10-11 16:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0081_auto_20190822_2250'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documents_thumb',
            name='path',
            field=models.TextField(),
        ),
        migrations.AlterField(
            model_name='documents_thumb10',
            name='path',
            field=models.TextField(),
        ),
    ]
