# Generated by Django 2.2.1 on 2019-05-24 10:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0036_auto_20190524_0932'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='demand',
            options={'verbose_name': 'Запуск'},
        ),
    ]
