# Generated by Django 2.1.7 on 2019-03-28 11:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0007_auto_20190328_0705'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_line',
            name='parent',
            field=models.ManyToManyField(to='ckk.Item_line'),
        ),
    ]
