# Generated by Django 2.2.8 on 2019-12-13 20:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0098_uploades_lotsman_documents'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='lotsman_documents_attributes',
            name='attr_type',
        ),
        migrations.RemoveField(
            model_name='lotsman_documents_attributes',
            name='document',
        ),
        migrations.RemoveField(
            model_name='lotsman_documents_thumb',
            name='document',
        ),
        migrations.RemoveField(
            model_name='lotsman_documents_thumb10',
            name='document',
        ),
        migrations.AlterUniqueTogether(
            name='uploades_lotsman_documents',
            unique_together=None,
        ),
        migrations.RemoveField(
            model_name='uploades_lotsman_documents',
            name='document',
        ),
        migrations.RemoveField(
            model_name='uploades_lotsman_documents',
            name='upload',
        ),
        migrations.DeleteModel(
            name='Lotsman_documents',
        ),
        migrations.DeleteModel(
            name='Lotsman_documents_attributes',
        ),
        migrations.DeleteModel(
            name='Lotsman_documents_thumb',
        ),
        migrations.DeleteModel(
            name='Lotsman_documents_thumb10',
        ),
        migrations.DeleteModel(
            name='Uploades_lotsman_documents',
        ),
    ]
