# Generated by Django 3.0.2 on 2020-01-17 18:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0165_auto_20200117_1600'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operations',
            name='planing_operation_type',
        ),
    ]
