# Generated by Django 2.2.2 on 2019-06-10 09:53

from django.db import migrations
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0046_auto_20190610_0953'),
        ('ckk', '0086_auto_20190609_2307'),
    ]

    operations = [
        migrations.RenameField(
            model_name='item_line',
            old_name='STMP_2',
            new_name='SPC_CLM_MARK',
        ),
        migrations.RenameField(
            model_name='item_line',
            old_name='STMP_1',
            new_name='SPC_CLM_NAME',
        ),
        migrations.AlterField(
            model_name='item_line',
            name='section',
            field=isc_common.fields.name_field.NameField(),
        ),
        migrations.AlterField(
            model_name='item_line',
            name='subsection',
            field=isc_common.fields.name_field.NameField(),
        ),
        migrations.AlterUniqueTogether(
            name='item_line',
            unique_together={('SPC_CLM_NAME', 'SPC_CLM_MARK'), ('parent', 'child')},
        ),
    ]
