# Generated by Django 2.2.6 on 2019-10-23 22:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0089_auto_20191023_2143'),
    ]

    operations = [
        migrations.RenameField(
            model_name='precent_items',
            old_name='precent',
            new_name='precent_dogovor',
        ),
        migrations.RenameField(
            model_name='precent_items',
            old_name='itemtype',
            new_name='precent_item_type',
        ),
    ]
