# Generated by Django 3.0.3 on 2020-02-27 14:04

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0212_auto_20200225_1013'),
        ('production', '0215_auto_20200227_1111'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations_template_detail',
            name='ed_izm',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, default=None, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AddField(
            model_name='operations_template_detail',
            name='num',
            field=models.PositiveIntegerField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='operations_template_detail',
            name='qty',
            field=models.PositiveIntegerField(blank=True, default=None, null=True),
        ),
    ]
