# Generated by Django 3.0.3 on 2020-02-08 14:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0134_auto_20200208_1419'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='lotsman_documents_hierarcy_refs',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.UniqueConstraint(condition=models.Q(('parent', None), ('section', None), ('subsection', None)), fields=('child',), name='Lotsman_documents_hierarcy_refs_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.UniqueConstraint(condition=models.Q(('section', None), ('subsection', None)), fields=('child', 'parent'), name='Lotsman_documents_hierarcy_refs_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.UniqueConstraint(condition=models.Q(('parent', None), ('subsection', None)), fields=('child', 'section'), name='Lotsman_documents_hierarcy_refs_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.UniqueConstraint(condition=models.Q(subsection=None), fields=('child', 'parent', 'section'), name='Lotsman_documents_hierarcy_refs_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.UniqueConstraint(condition=models.Q(('parent', None), ('section', None)), fields=('child', 'subsection'), name='Lotsman_documents_hierarcy_refs_unique_constraint_4'),
        ),
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.UniqueConstraint(condition=models.Q(section=None), fields=('child', 'parent', 'subsection'), name='Lotsman_documents_hierarcy_refs_unique_constraint_5'),
        ),
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.UniqueConstraint(condition=models.Q(parent=None), fields=('child', 'section', 'subsection'), name='Lotsman_documents_hierarcy_refs_unique_constraint_6'),
        ),
        migrations.AddConstraint(
            model_name='lotsman_documents_hierarcy_refs',
            constraint=models.UniqueConstraint(fields=('child', 'parent', 'section', 'subsection'), name='Lotsman_documents_hierarcy_refs_unique_constraint_7'),
        ),
    ]
