# Generated by Django 2.2.6 on 2019-10-22 07:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0076_auto_20191022_0722'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Operations_refs',
        ),
    ]
