# Generated by Django 2.2 on 2019-04-13 10:03

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0004_auto_20190328_1018'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attrs',
            name='document',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='kd.Documents', verbose_name='Документ'),
        ),
    ]
