# Generated by Django 2.2.1 on 2019-05-29 06:09

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0047_precent_item_line_view'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='precent_item_line_view',
            table='precent_item_line_view',
        ),
    ]
