# Generated by Django 3.0.3 on 2020-02-15 19:17

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0210_auto_20200212_0752'),
        ('production', '0180_ready_2_launch_detail_json'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ready_2_launch_detail',
            name='item',
        ),
        migrations.RemoveField(
            model_name='ready_2_launch_detail',
            name='json',
        ),
        migrations.AddField(
            model_name='ready_2_launch_detail',
            name='item_refs',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, to='ckk.Item_refs'),
        ),
    ]
