# Generated by Django 3.0.3 on 2020-02-08 14:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0170_auto_20200131_1114'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='launch_item_refs',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='launch_item_refs',
            constraint=models.UniqueConstraint(condition=models.Q(parent=None), fields=('child', 'launch'), name='Launch_item_refs_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='launch_item_refs',
            constraint=models.UniqueConstraint(fields=('child', 'launch', 'parent'), name='Launch_item_refs_unique_constraint_1'),
        ),
    ]
