# Generated by Django 2.2.1 on 2019-05-29 13:08

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0069_materials_material_1c'),
        ('production', '0035_operation_resources'),
    ]

    operations = [
        migrations.CreateModel(
            name='Operation_material',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('material', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Materials')),
                ('operation', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operations')),
            ],
            options={
                'verbose_name': 'Кросс таблица',
            },
        ),
    ]
