# Generated by Django 2.2.3 on 2019-07-20 07:29

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0066_delete_documents_history'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='document_attributes',
            name='props',
        ),
        migrations.AddField(
            model_name='document_attr_cross',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('copied', 'Копированный')), db_index=True, default=1),
        ),
        migrations.AlterField(
            model_name='documents',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('beenItemed', 'Был внесен в состав изделий'), ('modified', 'Был модифицирован')), db_index=True, default=1),
        ),
    ]
