# Generated by Django 2.2.3 on 2019-07-14 09:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0058_auto_20190714_0852'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='uploades_documents',
            unique_together={('upload', 'document')},
        ),
    ]
