# Generated by Django 2.2.3 on 2019-07-09 02:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0049_demand_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='long_name',
            field=models.TextField(blank=True, null=True, verbose_name='Полное наименование'),
        ),
        migrations.RunSQL(
            f"""update sales_customer set long_name = full_name"""
        ),
    ]
