# Generated by Django 3.0.2 on 2020-01-19 07:59

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0166_remove_operations_planing_operation_type'),
        ('planing', '0062_operations_description'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operation_launches',
            name='launch',
        ),
        migrations.AddField(
            model_name='operation_launches',
            name='launch_operations_item',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, related_name='planing_resource_launch', to='production.Launch_operations_item'),
        ),
    ]
