# Generated by Django 2.2.8 on 2019-12-04 20:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0142_resource_users_props'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations_item',
            name='q_paralel',
            field=models.PositiveIntegerField(default=1),
        ),
    ]
