# Generated by Django 2.2.7 on 2019-11-17 20:43

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0098_launches_view'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_operation_resources',
            name='operation_resources',
            field=isc_common.fields.related.ForeignKeySetNull(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='production.Operation_resources'),
        ),
        migrations.AlterField(
            model_name='launch_operations_material',
            name='operation_material',
            field=isc_common.fields.related.ForeignKeySetNull(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='production.Operation_material'),
        ),
    ]
