# Generated by Django 3.0.3 on 2020-02-22 10:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0105_operations_view_std_material'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='operations_view',
            options={'managed': False, 'verbose_name': 'Опреации системные'},
        ),
    ]
