# Generated by Django 2.2.8 on 2019-12-25 11:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0163_launches_props'),
    ]

    operations = [
        migrations.RenameField(
            model_name='operation_resources',
            old_name='q_paralel',
            new_name='batch_size',
        ),
        migrations.RemoveField(
            model_name='launch_operation_resources',
            name='q_paralel',
        ),
        migrations.AddField(
            model_name='launch_operation_resources',
            name='batch_size',
            field=models.PositiveIntegerField(default=1),
        ),
    ]
