# Generated by Django 2.2.1 on 2019-05-23 16:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0023_precent_operation_plan_templates'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='precent',
            name='operation_plan_templates',
        ),
    ]
