# Generated by Django 2.2 on 2019-04-25 17:05

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0039_auto_20190425_1146'),
        ('production', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='operation_plan_template_locations',
            options={'verbose_name': 'место положение для операций планирования'},
        ),
        migrations.AddField(
            model_name='operation_plan_template_locations',
            name='location',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
        migrations.AddField(
            model_name='operation_plan_template_locations',
            name='operation_plan_templates',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='production.Operation_plan_templates'),
        ),
    ]
