# Generated by Django 2.2 on 2019-04-20 12:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0034_auto_20190419_0536'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item_line',
            unique_together={('parent', 'child')},
        ),
        migrations.RemoveField(
            model_name='item_line',
            name='document',
        ),
    ]
