# Generated by Django 3.0.3 on 2020-02-26 12:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0210_auto_20200226_1030'),
    ]

    # operations = [
    #     migrations.RemoveConstraint(
    #         model_name='resource',
    #         name='Resource_unique_constraint_0',
    #     ),
    #     migrations.RemoveConstraint(
    #         model_name='resource',
    #         name='Resource_unique_constraint_1',
    #     ),
    # ]
