# Generated by Django 2.2.5 on 2019-09-18 01:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0063_auto_20190828_2056'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operations_plan_refs',
            name='child',
        ),
        migrations.RemoveField(
            model_name='operations_plan_refs',
            name='parent',
        ),
        migrations.RemoveField(
            model_name='operationsplan',
            name='item',
        ),
        migrations.RemoveField(
            model_name='operationsplan',
            name='location',
        ),
        migrations.RemoveField(
            model_name='operationsplan',
            name='status',
        ),
        migrations.RemoveField(
            model_name='operationsplan',
            name='type',
        ),
        migrations.DeleteModel(
            name='Operations_plan_view',
        ),
        migrations.DeleteModel(
            name='Operation_plan_types',
        ),
        migrations.DeleteModel(
            name='Operations_plan_refs',
        ),
        migrations.DeleteModel(
            name='OperationsPlan',
        ),
    ]
