# Generated by Django 3.0.3 on 2020-02-18 12:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0096_operation_operation'),
    ]

    # operations = [
    #     migrations.AlterModelOptions(
    #         name='operations_view',
    #         options={},
    #     ),
    # ]
