# Generated by Django 3.0.3 on 2020-02-17 12:21

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0210_auto_20200212_0752'),
        ('production', '0191_auto_20200217_1221'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs',
            name='item_full_name',
            field=models.TextField(),
        ),
        migrations.AlterField(
            model_name='launch_item_refs',
            name='item_refs',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Item_refs'),
        ),
    ]
