# Generated by Django 2.2.8 on 2019-12-13 12:52

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0088_auto_20191213_1252'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lotsman_documents',
            name='attr_type',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Attr_type', verbose_name='Тип атрибута'),
        ),
    ]
