# Generated by Django 2.2.7 on 2019-11-17 11:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0089_auto_20191117_1110'),
        ('sales', '0112_auto_20191117_0448'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Status_launch',
        ),
    ]
