# Generated by Django 2.2.8 on 2019-12-07 10:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0163_locations_users'),
        ('production', '0157_auto_20191207_1031'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('item', 'num')},
        ),
    ]
