# Generated by Django 2.2.8 on 2019-12-12 18:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0167_auto_20191212_1745'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Item_refs_hierarcy',
        ),
    ]
