# Generated by Django 2.2.4 on 2019-08-22 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0080_remove_pathes_props'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='document_attributes',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='documents',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='documents_history',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='documents_thumb',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='documents_thumb10',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='pathes',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='uploades',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='uploades_documents',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='uploades_log',
            name='id_old',
        ),
    ]
