# Generated by Django 2.2.8 on 2019-12-08 17:31

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0053_auto_20191208_1001'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_item',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_locations',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='planing_operation_loc', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_material',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='planing_operation', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_refs',
            name='income',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='operation_income', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_refs',
            name='outcome',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='operation_outcome', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_resources',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='planing_operation_res', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_standard_prod',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='planing.Operations'),
        ),
    ]
