# Generated by Django 3.0.3 on 2020-02-06 15:40

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0130_auto_20200206_1526'),
        ('ckk', '0191_auto_20200206_1206'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_image_refs',
            name='thumb',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='kd.Documents_thumb'),
        ),
        migrations.AlterField(
            model_name='item_image_refs',
            name='thumb10',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='kd.Documents_thumb10'),
        ),
    ]
