# Generated by Django 2.2.3 on 2019-07-14 08:52

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0057_pathes_prefix'),
    ]

    operations = [
        migrations.AlterField(
            model_name='uploades',
            name='path',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='kd.Pathes'),
        ),
    ]
