# Generated by Django 2.2.1 on 2019-05-17 17:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('capacity', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='resources',
            name='type',
        ),
        migrations.DeleteModel(
            name='Resources_type',
        ),
    ]
