# Generated by Django 3.0.3 on 2020-02-23 15:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0204_auto_20200223_1524'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs',
            name='qty',
            field=models.FloatField(blank=True, null=True),
        ),
    ]
