# Generated by Django 2.2.6 on 2019-10-14 15:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0156_auto_20191014_0942'),
    ]

    operations = [
        migrations.AddField(
            model_name='item_line',
            name='section_num',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
