# Generated by Django 3.0.5 on 2020-04-13 14:50

import bitfield.models
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0220_auto_20200330_1356'),
    ]

    operations = [
        migrations.CreateModel(
            name='Item_qty',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('qty', models.PositiveIntegerField()),
                ('props', bitfield.models.BitField((('items', 'Состав изделия'), ('teach', 'Технологическая спецификация')), db_index=True, default=1)),
                ('child', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='Item_qty_child', to='ckk.Item')),
                ('parent', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Item_qty_parent', to='ckk.Item')),
            ],
            options={
                'verbose_name': 'Количество элементов',
            },
        ),
    ]
