# Generated by Django 3.0.4 on 2020-03-05 17:29

import bitfield.models
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0124_operation_value_props'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Production_order_values',
        ),
        migrations.CreateModel(
            name='Production_order_detail',
            fields=[
            ],
            options={
                'verbose_name': 'Заказы на производство',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('planing.operations_view',),
        ),
        migrations.AlterField(
            model_name='operation_value',
            name='props',
            field=bitfield.models.BitField((('perone', 'Из расчета на еденицу продукции'), ('used_in_release', 'Учавствовало в учете выпуска')), db_index=True, default=0),
        ),
        migrations.CreateModel(
            name='Production_order_values',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('date', models.DateTimeField(default=None)),
            ],
            options={
                'verbose_name': 'Списания',
                'db_table': 'planing_operations_values_view',
                'managed': False,
            },
        ),
    ]
