# Generated by Django 2.2.1 on 2019-05-21 15:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0050_auto_20190521_1517'),
    ]

    operations = [
        # migrations.RemoveField(
        #     model_name='status',
        #     name='id_owner',
        # ),
    ]
