# Generated by Django 2.2.1 on 2019-05-21 15:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0049_auto_20190521_1236'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='status',
            # unique_together={('id_owner', 'code_owner', 'code')},
            unique_together={('code_owner', 'code')},
        ),
        migrations.RemoveField(
            model_name='status',
            name='name_owner',
        ),
    ]
