# Generated by Django 2.2.8 on 2019-12-07 13:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0036_operation_launch_operation_material'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launch_item_refs_timing',
            name='ed_izm',
        ),
        migrations.RemoveField(
            model_name='launch_item_refs_timing',
            name='launch_item_refs',
        ),
        migrations.DeleteModel(
            name='Launch_item_timing_view',
        ),
        migrations.DeleteModel(
            name='Launch_item_refs_timing',
        ),
    ]
