# Generated by Django 2.2.8 on 2019-12-26 06:27

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0007_auto_20191225_2034'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contants',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
    ]
