# Generated by Django 2.2.6 on 2019-10-08 12:58

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0069_auto_20191008_1257'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_material',
            name='operation_item',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operations_item'),
        ),
        migrations.AlterField(
            model_name='operation_resources',
            name='operation_item',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operations_item'),
        ),
    ]
