# Generated by Django 3.0.3 on 2020-02-11 08:11

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0135_auto_20200208_1422'),
    ]

    operations = [
        migrations.AddField(
            model_name='lotsman_document_attr_cross',
            name='parent_document',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, related_name='Lotsman_document_attr_cross_parent_doc', to='kd.Lotsman_documents_hierarcy'),
        ),
        migrations.AlterField(
            model_name='lotsman_document_attr_cross',
            name='document',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='Lotsman_document_attr_cross_doc', to='kd.Lotsman_documents_hierarcy'),
        ),
    ]
