# Generated by Django 2.2.2 on 2019-06-06 09:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0076_auto_20190606_0920'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Item_production_specificationView',
        ),
    ]
