# Generated by Django 2.2.1 on 2019-05-25 13:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0028_auto_20190525_0954'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attrs',
            name='value_str',
            field=models.TextField(db_index=True, verbose_name='Значение атрибута'),
        ),
    ]
