# Generated by Django 2.2.8 on 2019-12-13 13:22

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0091_auto_20191213_1307'),
    ]

    operations = [
        migrations.AddField(
            model_name='lotsman_documents',
            name='upload',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, to='kd.Uploades'),
        ),
        migrations.AlterField(
            model_name='lotsman_documents_attributes',
            name='document',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='kd.Lotsman_documents'),
        ),
    ]
