# Generated by Django 3.0.3 on 2020-03-02 05:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0227_auto_20200302_0422'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launch_item_line',
            name='SPC_CLM_COUNT_PER_ONE',
        ),
    ]
