# Generated by Django 2.2.1 on 2019-05-29 10:22

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0068_auto_20190529_0628'),
    ]

    operations = [
        migrations.AddField(
            model_name='materials',
            name='material_1C',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='one_c.Documents_param_1c'),
        ),
    ]
