# Generated by Django 3.0.3 on 2020-02-11 08:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0137_auto_20200211_0811'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='lotsman_document_attr_cross',
            unique_together={('document', 'parent_document', 'attribute')},
        ),
    ]
