# Generated by Django 2.2.3 on 2019-07-08 15:44

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0128_auto_20190707_2035'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ed_izm',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
    ]
