# Generated by Django 2.2.7 on 2019-11-19 07:26

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0112_auto_20191118_2128'),
    ]

    operations = [
        migrations.AddField(
            model_name='launch_item_line',
            name='added_parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_added_parent', to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='launch_item_line',
            name='child',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_child', to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='launch_item_line',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_parent', to='ckk.Item'),
        ),
    ]
