# Generated by Django 2.2 on 2019-04-17 18:21

import bitfield.models
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0020_cdw_attrs_spw_attrs'),
        ('ckk', '0024_auto_20190417_0107'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('from_cdw', 'Получено из чертежа')), default=1),
        ),
        migrations.CreateModel(
            name='Item_image_refs',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('item', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Item')),
                ('thumb', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents_thumb')),
                ('thumb10', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents_thumb10')),
            ],
            options={
                'verbose_name': 'Кросс таблица на местоположения графических элементов',
            },
        ),
    ]
